@@ -64,11 +64,11 @@ rm "$TARGET/www/assets/js/stylesheet.js"*
 rm "$TARGET/.editorconfig"
 rm "$TARGET/.gitattributes"
 rm -r "$TARGET/.github"
-rm "$TARGET/.php_cs.dist"
-rm "$TARGET/codecov.yml"
-rm "$TARGET/phpcs.xml"
-rm "$TARGET/psalm.xml"
-rm "$TARGET"/{,modules}/.gitignore
+rm "$TARGET"/{,modules/*}/.php_cs.dist
+rm "$TARGET"/{,modules/*}/codecov.yml
+rm "$TARGET"/{,modules/*}/phpcs.xml
+rm "$TARGET"/{,modules/*}/psalm.xml
+rm "$TARGET"/{,modules/*}/.gitignore
 rm "$TARGET"/{cache,config,metadata,locales}/.gitkeep
 rm "$TARGET/composer.phar"
 tar --owner 0 --group 0 -cvzf "$TARGET.tar.gz" "$TARGET"
