@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Auth;
 
 use SimpleSAML\Configuration;
@@ -307,11 +309,8 @@ abstract class Source
      * @return \SimpleSAML\Auth\Source The parsed authentication source.
      * @throws \Exception If the authentication source is invalid.
      */
-    private static function parseAuthSource($authId, $config)
+    private static function parseAuthSource(string $authId, array $config): Source
     {
-        assert(is_string($authId));
-        assert(is_array($config));
-
         self::validateSource($config, $authId);
 
         $id = $config[0];
