@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace SimpleSAML;
 
+use Exception;
 use PDO;
 use PDOException;
 use PDOStatement;
@@ -83,7 +84,7 @@ class Database
     {
         $driverOptions = $config->getArray('database.driver_options', []);
         if ($config->getBoolean('database.persistent', true)) {
-            $driverOptions = [PDO::ATTR_PERSISTENT => true];
+            $driverOptions[PDO::ATTR_PERSISTENT] = true;
         }
 
         // connect to the master
@@ -127,7 +128,7 @@ class Database
                 'database.username'   => $config->getString('database.username', null),
                 'database.password'   => $config->getString('database.password', null),
                 'database.prefix'     => $config->getString('database.prefix', ''),
-                'database.persistent' => $config->getBoolean('database.persistent', false),
+                'database.persistent' => $config->getBoolean('database.persistent', true),
             ],
             'slaves' => $config->getArray('database.slaves', []),
         ];
@@ -155,7 +156,7 @@ class Database
 
             return $db;
         } catch (PDOException $e) {
-            throw new \Exception("Database error: " . $e->getMessage());
+            throw new Exception("Database error: " . $e->getMessage());
         }
     }
 
@@ -218,7 +219,7 @@ class Database
             return $query;
         } catch (PDOException $e) {
             $this->lastError = $db->errorInfo();
-            throw new \Exception("Database error: " . $e->getMessage());
+            throw new Exception("Database error: " . $e->getMessage());
         }
     }
 
@@ -238,7 +239,7 @@ class Database
             return $db->exec($stmt);
         } catch (PDOException $e) {
             $this->lastError = $db->errorInfo();
-            throw new \Exception("Database error: " . $e->getMessage());
+            throw new Exception("Database error: " . $e->getMessage());
         }
     }
 
@@ -288,4 +289,15 @@ class Database
     {
         return $this->lastError;
     }
+
+
+    /**
+     * Return the name of the PDO-driver
+     *
+     * @return string
+     */
+    public function getDriver(): string
+    {
+        return $this->dbMaster->getAttribute(PDO::ATTR_DRIVER_NAME);
+    }
 }
