@@ -61,7 +61,12 @@ class Assertion extends Exception
     {
 
         assert_options(ASSERT_WARNING, 0);
-        assert_options(ASSERT_QUIET_EVAL, 0);
+        if (version_compare(PHP_VERSION, '8.0.0', '<')) {
+            assert_options(ASSERT_QUIET_EVAL, 0);
+        } else {
+            ini_set('assert.exception', '0');
+            ini_set('assert.warning', '1');
+        }
         assert_options(ASSERT_CALLBACK, [Assertion::class, 'onAssertion']);
     }
 
