@@ -1,7 +1,12 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Error;
 
+use PDOException;
+use Throwable;
+
 /**
  * Class for saving normal exceptions for serialization.
  *
@@ -28,17 +33,17 @@ class UnserializableException extends Exception
     /**
      * Create a serializable exception representing an unserializable exception.
      *
-     * @param \Exception $original  The original exception.
+     * @param \Throwable $original  The original exception.
      */
-    public function __construct(\Exception $original)
+    public function __construct(Throwable $original)
     {
 
         $this->class = get_class($original);
         $msg = $original->getMessage();
         $code = $original->getCode();
 
-        if ($original instanceof \PDOException) {
-            // PDOException uses a string as the code. Filter it out here.
+        if (!is_int($code)) {
+            // PDOException and possibly others use a string for the code. Filter it out here.
             $code = -1;
         }
 
