@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Metadata;
 
 use RobRichards\XMLSecLibs\XMLSecurityKey;
@@ -30,7 +32,7 @@ class Signer
      * @return array An associative array with the keys 'privatekey', 'certificate', and optionally 'privatekey_pass'.
      * @throws \Exception If the key and certificate used to sign is unknown.
      */
-    private static function findKeyCert($config, $entityMetadata, $type)
+    private static function findKeyCert(Configuration $config, array $entityMetadata, string $type): array
     {
         // first we look for metadata.privatekey and metadata.certificate in the metadata
         if (
@@ -130,7 +132,7 @@ class Signer
      * @return boolean True if metadata signing is enabled, false otherwise.
      * @throws \Exception If the value of the 'metadata.sign.enable' option is not a boolean.
      */
-    private static function isMetadataSigningEnabled($config, $entityMetadata, $type)
+    private static function isMetadataSigningEnabled(Configuration $config, array $entityMetadata, string $type): bool
     {
         // first check the metadata for the entity
         if (array_key_exists('metadata.sign.enable', $entityMetadata)) {
@@ -166,8 +168,11 @@ class Signer
      *
      * @throws \SimpleSAML\Error\CriticalConfigurationError
      */
-    private static function getMetadataSigningAlgorithm($config, $entityMetadata, $type)
-    {
+    private static function getMetadataSigningAlgorithm(
+        Configuration $config,
+        array $entityMetadata,
+        string $type
+    ): array {
         // configure the algorithm to use
         if (array_key_exists('metadata.sign.algorithm', $entityMetadata)) {
             if (!is_string($entityMetadata['metadata.sign.algorithm'])) {
