@@ -2,6 +2,8 @@
 
 namespace SimpleSAML\Module\adfs\SAML2\XML\fed;
 
+use Webmozart\Assert\Assert;
+
 /**
  * Class representing SecurityTokenServiceType RoleDescriptor.
  *
@@ -33,6 +35,8 @@ class SecurityTokenServiceType extends \SAML2\XML\md\RoleDescriptor
     public function __construct(\DOMElement $xml = null)
     {
         parent::__construct('RoleDescriptor', $xml);
+        parent::setProtocolSupportEnumeration($this->protocolSupportEnumeration);
+
         if ($xml === null) {
             return;
         }
@@ -44,14 +48,14 @@ class SecurityTokenServiceType extends \SAML2\XML\md\RoleDescriptor
      * @param \DOMElement $parent  The element we should add this contact to.
      * @return \DOMElement  The new ContactPerson-element.
      */
-    public function toXML(\DOMElement $parent)
+    public function toXML(\DOMElement $parent): \DOMElement
     {
+        Assert::string($this->Location);
+
         if (is_null($this->Location)) {
             throw new \Exception('Location not set');
         }
 
-        assert(is_string($this->Location));
-
         $e = parent::toXML($parent);
         $e->setAttributeNS('http://www.w3.org/2000/xmlns/', 'xmlns:fed', Constants::NS_FED);
         $e->setAttributeNS(\SAML2\Constants::NS_XSI, 'xsi:type', 'fed:SecurityTokenServiceType');
