@@ -26,7 +26,7 @@ if (array_key_exists('code', $_REQUEST)) {
     // newer API, but the parameter name has changed to error. It doesn't hurt
     // to preserve support for this, so this is left in as a placeholder.
     // redirect them to their original page so they can choose another auth mechanism
-    if ($_REQUEST['error'] === 'user_denied') {
+    if (($_REQUEST['error'] === 'user_denied') && ($state !== null)) {
         $e = new \SimpleSAML\Error\UserAborted();
         \SimpleSAML\Auth\State::throwException($state, $e);
     }
@@ -35,10 +35,12 @@ if (array_key_exists('code', $_REQUEST)) {
     throw new \Exception('Authentication failed: ['.$_REQUEST['error'].'] '.$_REQUEST['error_description']);
 }
 
-// find authentication source
 assert(array_key_exists(\SimpleSAML\Module\authwindowslive\Auth\Source\LiveID::AUTHID, $state));
+
+// find authentication source
 $sourceId = $state[\SimpleSAML\Module\authwindowslive\Auth\Source\LiveID::AUTHID];
 
+/** @var \SimpleSAML\Module\authwindowslive\Auth\Source\LiveID|null $source */
 $source = \SimpleSAML\Auth\Source::getById($sourceId);
 if ($source === null) {
     throw new \Exception('Could not find authentication source with id '.$sourceId);
