@@ -1,5 +1,9 @@
 <?php
 
+use Webmozart\Assert\Assert;
+
+use \SimpleSAML\Module\cas\Auth\Source\CAS;
+
 /**
  * Handle linkback() response from CAS.
  */
@@ -7,7 +11,7 @@
 if (!isset($_GET['stateID'])) {
     throw new \SimpleSAML\Error\BadRequest('Missing stateID parameter.');
 }
-$state = \SimpleSAML\Auth\State::loadState($_GET['stateID'], \SimpleSAML\Module\cas\Auth\Source\CAS::STAGE_INIT);
+$state = \SimpleSAML\Auth\State::loadState($_GET['stateID'], CAS::STAGE_INIT);
 
 if (!isset($_GET['ticket'])) {
     throw new \SimpleSAML\Error\BadRequest('Missing ticket parameter.');
@@ -15,9 +19,10 @@ if (!isset($_GET['ticket'])) {
 $state['cas:ticket'] = (string) $_GET['ticket'];
 
 // Find authentication source
-assert(array_key_exists(\SimpleSAML\Module\cas\Auth\Source\CAS::AUTHID, $state));
-$sourceId = $state[\SimpleSAML\Module\cas\Auth\Source\CAS::AUTHID];
+Assert::keyExists($state, CAS::AUTHID);
+$sourceId = $state[CAS::AUTHID];
 
+/** @var \SimpleSAML\Module\cas\Auth\Source\CAS|null $source */
 $source = \SimpleSAML\Auth\Source::getById($sourceId);
 if ($source === null) {
     throw new \Exception('Could not find authentication source with id '.$sourceId);
