@@ -1,7 +1,7 @@
 <?php
 
-$config = array(
-    'example.org' => array(
+$config = [
+    'example.org' => [
         /*
          * The shared key for this CDC server.
          */
@@ -18,5 +18,5 @@ $config = array(
          * If this is 0, the cookie will expire when the browser is closed.
          */
         'cookie.lifetime' => 0,
-    ),
-);
+    ],
+];
