@@ -144,6 +144,11 @@ abstract class Store
         );
 
         unset($config[0]);
-        return new $className($config);
+        /**
+         * @psalm-suppress InvalidStringClass
+         * @var \SimpleSAML\Module\consent\Store $retval
+         */
+        $retval = new $className($config);
+        return $retval;
     }
 }
