@@ -31,7 +31,9 @@ if (!array_key_exists('StateId', $_REQUEST)) {
 $id = $_REQUEST['StateId'];
 $state = \SimpleSAML\Auth\State::loadState($id, 'consent:request');
 
-if (array_key_exists('core:SP', $state)) {
+if (is_null($state)) {
+    throw new \SimpleSAML\Error\NoState;
+} elseif (array_key_exists('core:SP', $state)) {
     $spentityid = $state['core:SP'];
 } elseif (array_key_exists('saml:sp:State', $state)) {
     $spentityid = $state['saml:sp:State']['core:SP'];
@@ -158,8 +160,12 @@ $t->data['srcName'] = $srcName;
 $t->data['dstName'] = $dstName;
 
 // Fetch privacypolicy
-if (array_key_exists('privacypolicy', $state['Destination'])) {
+if (array_key_exists('UIInfo', $state['Destination']) && array_key_exists('PrivacyStatementURL', $state['Destination']['UIInfo']) && (!empty($state['Destination']['UIInfo']['PrivacyStatementURL']))) {
+    $privacypolicy = reset($state['Destination']['UIInfo']['PrivacyStatementURL']);
+} elseif (array_key_exists('privacypolicy', $state['Destination'])) {
     $privacypolicy = $state['Destination']['privacypolicy'];
+} elseif (array_key_exists('UIInfo', $state['Source']) && array_key_exists('PrivacyStatementURL', $state['Source']['UIInfo']) && (!empty($state['Source']['UIInfo']['PrivacyStatementURL']))) {
+    $privacypolicy = reset($state['Source']['UIInfo']['PrivacyStatementURL']);
 } elseif (array_key_exists('privacypolicy', $state['Source'])) {
     $privacypolicy = $state['Source']['privacypolicy'];
 } else {
@@ -209,7 +215,7 @@ $t->show();
  *
  * @return string HTML representation of the attributes
  */
-function present_attributes($t, $attributes, $nameParent)
+function present_attributes(\SimpleSAML\XHTML\Template $t, array $attributes, $nameParent)
 {
     $translator = $t->getTranslator();
 
@@ -248,6 +254,7 @@ function present_attributes($t, $attributes, $nameParent)
                 $hiddenId = \SimpleSAML\Utils\Random::generateID();
                 $str .= '<td><span class="attrvalue hidden" id="hidden_'.$hiddenId.'">';
             } else {
+                $hiddenId = '';
                 $str .= '<td><span class="attrvalue">';
             }
 
@@ -279,7 +286,7 @@ function present_attributes($t, $attributes, $nameParent)
                 $str .= '... ';
                 $str .= '<a class="consent_showattributelink" href="javascript:SimpleSAML_show(\'hidden_'.$hiddenId;
                 $str .= '\'); SimpleSAML_hide(\'visible_'.$hiddenId.'\');">';
-                $str .= $t->t('{consent:consent:show_attribute}');
+                $str .= $translator->t('{consent:consent:show_attribute}');
                 $str .= '</a>';
                 $str .= '</div>';
             }
@@ -287,6 +294,6 @@ function present_attributes($t, $attributes, $nameParent)
             $str .= '</td></tr>';
         }       // end else: not child table
     }   // end foreach
-    $str .= isset($attributes) ? '</table>' : '';
+    $str .= '</table>';
     return $str;
 }
