@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Module\core\Auth\Process;
 
 use SimpleSAML\Logger;
@@ -102,10 +104,8 @@ class GenerateGroups extends \SimpleSAML\Auth\ProcessingFilter
      * @param array $attributes  The attributes of the user.
      * @return string|null  The realm of the user, or NULL if we are unable to determine the realm.
      */
-    private static function getRealm($attributes)
+    private static function getRealm(array $attributes): ?string
     {
-        assert(is_array($attributes));
-
         if (!array_key_exists('eduPersonPrincipalName', $attributes)) {
             return null;
         }
@@ -136,10 +136,8 @@ class GenerateGroups extends \SimpleSAML\Auth\ProcessingFilter
      * @param string $string  The string which should be escaped.
      * @return string  The escaped string.
      */
-    private static function escapeIllegalChars($string)
+    private static function escapeIllegalChars(string $string): string
     {
-        assert(is_string($string));
-
         return preg_replace_callback(
             '/([^a-zA-Z0-9_@=.])/',
             /**
