@@ -89,9 +89,9 @@ class File extends \SimpleSAML\Stats\Output
         assert(isset($data['time']));
 
         $time = $data['time'];
-        $milliseconds = (int) (($time - (int) $time) * 1000);
+        $milliseconds = intval((($time - intval($time)) * 1000));
 
-        $timestamp = gmdate('Y-m-d\TH:i:s', $time) . sprintf('.%03dZ', $milliseconds);
+        $timestamp = gmdate('Y-m-d\TH:i:s', intval($time)) . sprintf('.%03dZ', $milliseconds);
 
         $outDate = substr($timestamp, 0, 10); // The date-part of the timstamp
 
