@@ -8,4 +8,7 @@
  *
  * @package SimpleSAMLphp
  */
-sspmod_exampleauth_Auth_Source_External::resume();
+
+namespace SimpleSAML\Module\exampleauth\Auth\Source;
+
+External::resume();
