@@ -2,12 +2,6 @@
 
 namespace SimpleSAML\Module\expirycheck\Auth\Process;
 
-use SimpleSAML\Auth;
-use SimpleSAML\Logger;
-use SimpleSAML\Module;
-use SimpleSAML\Utils;
-use Webmozart\Assert\Assert;
-
 /**
  * Filter which show "about to expire" warning or deny access if netid is expired.
  *
@@ -52,7 +46,7 @@ class ExpiryDate extends \SimpleSAML\Auth\ProcessingFilter
     {
         parent::__construct($config, $reserved);
 
-        Assert::isArray($config);
+        assert(is_array($config));
 
         if (array_key_exists('warndaysbefore', $config)) {
             $this->warndaysbefore = $config['warndaysbefore'];
@@ -146,32 +140,32 @@ class ExpiryDate extends \SimpleSAML\Auth\ProcessingFilter
         $expireOnDate = strtotime($state['Attributes'][$this->expirydate_attr][0]);
 
         if ($this->shWarning($state, $expireOnDate, $this->warndaysbefore)) {
-            Assert::isArray($state);
+            assert(is_array($state));
             if (isset($state['isPassive']) && $state['isPassive'] === true) {
                 // We have a passive request. Skip the warning.
                 return;
             }
 
-            Logger::warning('expirycheck: NetID '.$netId.' is about to expire!');
+            \SimpleSAML\Logger::warning('expirycheck: NetID '.$netId.' is about to expire!');
 
             // Save state and redirect
             $state['expireOnDate'] = date($this->date_format, $expireOnDate);
             $state['netId'] = $netId;
-            $id = Auth\State::saveState($state, 'expirywarning:about2expire');
-            $url = Module::getModuleURL('expirycheck/about2expire.php');
-            Utils\HTTP::redirectTrustedURL($url, ['StateId' => $id]);
+            $id = \SimpleSAML\Auth\State::saveState($state, 'expirywarning:about2expire');
+            $url = \SimpleSAML\Module::getModuleURL('expirycheck/about2expire.php');
+            \SimpleSAML\Utils\HTTP::redirectTrustedURL($url, ['StateId' => $id]);
         }
 
         if (!$this->checkDate($expireOnDate)) {
-            Logger::error('expirycheck: NetID '.$netId.
+            \SimpleSAML\Logger::error('expirycheck: NetID '.$netId.
                 ' has expired ['.date($this->date_format, $expireOnDate).']. Access denied!');
 
             /* Save state and redirect. */
             $state['expireOnDate'] = date($this->date_format, $expireOnDate);
             $state['netId'] = $netId;
-            $id = Auth\State::saveState($state, 'expirywarning:expired');
-            $url = Module::getModuleURL('expirycheck/expired.php');
-            Utils\HTTP::redirectTrustedURL($url, ['StateId' => $id]);
+            $id = \SimpleSAML\Auth\State::saveState($state, 'expirywarning:expired');
+            $url = \SimpleSAML\Module::getModuleURL('expirycheck/expired.php');
+            \SimpleSAML\Utils\HTTP::redirectTrustedURL($url, ['StateId' => $id]);
         }
     }
 }
