@@ -1,5 +1,7 @@
 <?php
 
+namespace SimpleSAML\Module\ldap\Auth\Source;
+
 /**
  * LDAP authentication source.
  *
@@ -10,9 +12,9 @@
  *
  * @package SimpleSAMLphp
  */
-class sspmod_ldap_Auth_Source_LDAPMulti extends sspmod_core_Auth_UserPassOrgBase
-{
 
+class LDAPMulti extends \SimpleSAML\Module\core\Auth\UserPassOrgBase
+{
     /**
      * An array with descriptions for organizations.
      */
@@ -43,25 +45,29 @@ class sspmod_ldap_Auth_Source_LDAPMulti extends sspmod_core_Auth_UserPassOrgBase
         // Call the parent constructor first, as required by the interface
         parent::__construct($info, $config);
 
-        $cfgHelper = SimpleSAML_Configuration::loadFromArray($config,
-            'Authentication source ' . var_export($this->authId, true));
+        $cfgHelper = \SimpleSAML\Configuration::loadFromArray(
+            $config,
+            'Authentication source '.var_export($this->authId, true)
+        );
 
 
-        $this->orgs = array();
-        $this->ldapOrgs = array();
+        $this->orgs = [];
+        $this->ldapOrgs = [];
         foreach ($config as $name => $value) {
-
             if ($name === 'username_organization_method') {
                 $usernameOrgMethod = $cfgHelper->getValueValidate(
                     'username_organization_method',
-                    array('none', 'allow', 'force'));
+                    ['none', 'allow', 'force']
+                );
                 $this->setUsernameOrgMethod($usernameOrgMethod);
                 continue;
             }
 
             if ($name === 'include_organization_in_username') {
                 $this->includeOrgInUsername = $cfgHelper->getBoolean(
-                    'include_organization_in_username', false);
+                    'include_organization_in_username',
+                    false
+                );
                 continue;
             }
 
@@ -74,9 +80,10 @@ class sspmod_ldap_Auth_Source_LDAPMulti extends sspmod_core_Auth_UserPassOrgBase
                 $this->orgs[$orgId] = $orgId;
             }
 
-            $orgCfg = new sspmod_ldap_ConfigHelper($orgCfg,
-                'Authentication source ' . var_export($this->authId, true) .
-                ', organization ' . var_export($orgId, true));
+            $orgCfg = new \SimpleSAML\Module\ldap\ConfigHelper(
+                $orgCfg,
+                'Authentication source '.var_export($this->authId, true).', organization '.var_export($orgId, true)
+            );
             $this->ldapOrgs[$orgId] = $orgCfg;
         }
     }
@@ -98,14 +105,14 @@ class sspmod_ldap_Auth_Source_LDAPMulti extends sspmod_core_Auth_UserPassOrgBase
 
         if (!array_key_exists($org, $this->ldapOrgs)) {
             // The user has selected an organization which doesn't exist anymore.
-            SimpleSAML\Logger::warning('Authentication source ' . var_export($this->authId, true) .
-                ': Organization seems to have disappeared while the user logged in.' .
-                ' Organization was ' . var_export($org, true));
-            throw new SimpleSAML_Error_Error('WRONGUSERPASS');
+            \SimpleSAML\Logger::warning('Authentication source '.var_export($this->authId, true).
+                ': Organization seems to have disappeared while the user logged in.'.
+                ' Organization was '.var_export($org, true));
+            throw new \SimpleSAML\Error\Error('WRONGUSERPASS');
         }
 
         if ($this->includeOrgInUsername) {
-            $username = $username . '@' . $org;
+            $username = $username.'@'.$org;
         }
 
         return $this->ldapOrgs[$org]->login($username, $password, $sasl_args);
