@@ -52,6 +52,12 @@ $config = [
                         ],
                     ],
 
+                    'regex-template' => [
+                        "#^https://www\.example\.com/sp$#" => [
+                            'assertion.encryption' => false,
+                        ],
+                    ],
+
                     /*
                      * The sets of entities to load, any combination of:
                      *  - 'saml20-idp-remote'
