@@ -223,6 +223,18 @@ class MetaLoader
                 $template = $source['template'];
             }
 
+            if (array_key_exists('regex-template', $source)) {
+                foreach ($source['regex-template'] as $e => $t) {
+                    if (preg_match($e, $entity->getEntityID())) {
+                        if (is_array($template)) {
+                            $template = array_merge($template, $t);
+                        } else {
+                            $template = $t;
+                        }
+                    }
+                }
+            }
+
             if (in_array('shib13-sp-remote', $this->types, true)) {
                 $this->addMetadata($source['src'], $entity->getMetadata1xSP(), 'shib13-sp-remote', $template);
             }
@@ -430,7 +442,7 @@ class MetaLoader
                 $this->stateFile,
                 "<?php\n/* This file was generated by the metarefresh module at ".$this->getTime().".\n".
                 " Do not update it manually as it will get overwritten. */\n".
-                '$state = '.var_export($this->state, true).";\n?>\n",
+                '$state = '.var_export($this->state, true).";\n\n",
                 0644
             );
         }
@@ -579,8 +591,6 @@ class MetaLoader
                     $content .= addslashes($entityID).'\'] = '.var_export($m['metadata'], true).';'."\n";
                 }
 
-                $content .= "\n".'?>';
-
                 Utils\System::writeFile($filename, $content, 0644);
             } elseif (is_file($filename)) {
                 if (unlink($filename)) {
@@ -655,7 +665,6 @@ class MetaLoader
     private function getTime()
     {
         // The current date, as a string
-        date_default_timezone_set('UTC');
-        return date('Y-m-d\\TH:i:s\\Z');
+        return gmdate('Y-m-d\\TH:i:s\\Z');
     }
 }
