@@ -10,23 +10,39 @@ require_once(dirname(dirname(__FILE__)).'/libextinc/OAuth.php');
  * @author Andreas Åkre Solberg, <andreas.solberg@uninett.no>, UNINETT AS.
  * @package SimpleSAMLphp
  */
-
 class Consumer
 {
+    /** @var \OAuthConsumer */
     private $consumer;
+
+    /** @var \OAuthSignatureMethod */
     private $signer;
 
+
+    /**
+     * @param string $key
+     * @param string $secret
+     */
     public function __construct($key, $secret)
     {
         $this->consumer = new \OAuthConsumer($key, $secret, null);
         $this->signer = new \OAuthSignatureMethod_HMAC_SHA1();
     }
 
-    // Used only to load the libextinc library early
+
+    /**
+     * Used only to load the libextinc library early
+     * @return void
+     */
     public static function dummy()
     {
     }
 
+
+    /**
+     * @param array $hrh
+     * @return string|null
+     */
     public static function getOAuthError($hrh)
     {
         foreach ($hrh as $h) {
@@ -37,6 +53,11 @@ class Consumer
         return null;
     }
 
+
+    /**
+     * @param array $hrh
+     * @return string|null
+     */
     public static function getContentType($hrh)
     {
         foreach ($hrh as $h) {
@@ -47,7 +68,8 @@ class Consumer
         return null;
     }
 
-    /*
+
+    /**
      * This static helper function wraps \SimpleSAML\Utils\HTTP::fetch
      * and throws an exception with diagnostics messages if it appear
      * to be failing on an OAuth endpoint.
@@ -55,18 +77,26 @@ class Consumer
      * If the status code is not 200, an exception is thrown. If the content-type
      * of the response if text/plain, the content of the response is included in
      * the text of the Exception thrown.
+     *
+     * @param string $url
+     * @param string $context
+     * @return string
+     * @throws \Exception
      */
     public static function getHTTP($url, $context = '')
     {
         try {
-            $response = \SimpleSAML\Utils\HTTP::fetch($url);
+            $response = \SimpleSAML\Utils\HTTP::fetch($url, [], false);
         } catch (\SimpleSAML\Error\Exception $e) {
             $statuscode = 'unknown';
+
+            /** @psalm-suppress UndefinedVariable */
             if (preg_match('/^HTTP.*\s([0-9]{3})/', $http_response_header[0], $matches)) {
                 $statuscode = $matches[1];
             }
 
             $error = $context.' [statuscode: '.$statuscode.']: ';
+            /** @psalm-suppress UndefinedVariable */
             $oautherror = self::getOAuthError($http_response_header);
 
             if (!empty($oautherror)) {
@@ -76,9 +106,17 @@ class Consumer
             throw new \Exception($error.':'.$url);
         }
         // Fall back to return response, if could not reckognize HTTP header. Should not happen.
+        /** @var string $response */
         return $response;
     }
 
+
+    /**
+     * @param string $url
+     * @param array|null $parameters
+     * @return \OAuthToken
+     * @throws \Exception
+     */
     public function getRequestToken($url, $parameters = null)
     {
         $req_req = \OAuthRequest::from_consumer_and_token($this->consumer, null, "GET", $url, $parameters);
@@ -101,6 +139,14 @@ class Consumer
         return new \OAuthToken($requestToken, $requestTokenSecret);
     }
 
+
+    /**
+     * @param string $url
+     * @param \OAuthToken $requestToken
+     * @param bool $redirect
+     * @param callable|null $callback
+     * @return string
+     */
     public function getAuthorizeRequest($url, $requestToken, $redirect = true, $callback = null)
     {
         $params = ['oauth_token' => $requestToken->key];
@@ -115,19 +161,29 @@ class Consumer
         return $authorizeURL;
     }
 
+
+    /**
+     * @param string $url
+     * @param \OAuthToken $requestToken
+     * @param array|null $parameters
+     * @return \OAuthToken
+     * @throws \Exception
+     */
     public function getAccessToken($url, $requestToken, $parameters = null)
     {
         $acc_req = \OAuthRequest::from_consumer_and_token($this->consumer, $requestToken, "GET", $url, $parameters);
         $acc_req->sign_request($this->signer, $this->consumer, $requestToken);
 
         try {
-            $response_acc = \SimpleSAML\Utils\HTTP::fetch($acc_req->to_url());
+            /** @var string $response_acc */
+            $response_acc = \SimpleSAML\Utils\HTTP::fetch($acc_req->to_url(), [], false);
         } catch (\SimpleSAML\Error\Exception $e) {
             throw new \Exception('Error contacting request_token endpoint on the OAuth Provider');
         }
 
         \SimpleSAML\Logger::debug('oauth: Reponse to get access token: '.$response_acc);
 
+        $accessResponseParsed = [];
         parse_str($response_acc, $accessResponseParsed);
 
         if (array_key_exists('error', $accessResponseParsed)) {
@@ -140,6 +196,14 @@ class Consumer
         return new \OAuthToken($accessToken, $accessTokenSecret);
     }
 
+
+    /**
+     * @param string $url
+     * @param \OAuthToken $accessToken
+     * @param array $parameters
+     * @return array|string
+     * @throws \SimpleSAML\Error\Exception
+     */
     public function postRequest($url, $accessToken, $parameters)
     {
         $data_req = \OAuthRequest::from_consumer_and_token($this->consumer, $accessToken, "POST", $url, $parameters);
@@ -167,13 +231,21 @@ class Consumer
         return $response;
     }
 
-    public function getUserInfo($url, $accessToken, $opts = null)
+
+    /**
+     * @param string $url
+     * @param \OAuthToken $accessToken
+     * @param array $opts
+     * @return array|null
+     */
+    public function getUserInfo($url, $accessToken, $opts = [])
     {
         $data_req = \OAuthRequest::from_consumer_and_token($this->consumer, $accessToken, "GET", $url, null);
         $data_req->sign_request($this->signer, $this->consumer, $accessToken);
 
+        /** @var string $data */
         $data = \SimpleSAML\Utils\HTTP::fetch($data_req->to_url(), $opts);
 
-        return  json_decode($data, true);
+        return json_decode($data, true);
     }
 }
