@@ -4,6 +4,7 @@
  * Hook to inject HTML content into all pages...
  *
  * @param array &$hookinfo  hookinfo
+ * @return void
  */
 function portal_hook_htmlinject(&$hookinfo)
 {
@@ -15,6 +16,8 @@ function portal_hook_htmlinject(&$hookinfo)
     $links = ['links' => []];
     \SimpleSAML\Module::callHooks('frontpage', $links);
 
+    assert(is_array($links));
+
     $portalConfig = \SimpleSAML\Configuration::getOptionalConfig('module_portal.php');
 
     $allLinks = [];
@@ -36,8 +39,8 @@ function portal_hook_htmlinject(&$hookinfo)
     $hookinfo['jquery']['css'] = true;
 
     // Header
-    $hookinfo['pre'][] = '<div id="portalmenu" class="ui-tabs ui-widget ui-widget-content ui-corner-all">'.
-        $portal->getMenu($hookinfo['page']).
+    $hookinfo['pre'][] = '<div id="portalmenu" class="ui-tabs ui-widget ui-widget-content ui-corner-all">' .
+        $portal->getMenu($hookinfo['page']) .
         '<div id="portalcontent" class="ui-tabs-panel ui-widget-content ui-corner-bottom">';
 
     // Footer
