@@ -1,7 +1,5 @@
 <?php
 
-namespace SimpleSAML\Module\riak;
-
 /*
  * Copyright (c) 2012 The University of Queensland
  *
@@ -28,6 +26,7 @@ namespace SimpleSAML\Module\riak;
  * Hook to run a cron job.
  *
  * @param array &$croninfo  Output
+ * @return void
  */
 function riak_hook_cron(&$croninfo)
 {
@@ -40,17 +39,22 @@ function riak_hook_cron(&$croninfo)
     }
 
     try {
-        $store = new \SimpleSAML\Module\riak\Store\Store();
-        $result = $store->bucket->indexSearch('expires', 'int', 1, time() - 30);
-        foreach ($result as $link) {
-            $link->getBinary()->delete();
+        $store = new \SimpleSAML\Module\riak\Store\Riak();
+        $result = $store->getExpired();
+
+        if ($result === null) {
+            $result = [];
+        } else {
+            foreach ($result as $key) {
+                $store->delete('session', $key);
+            }
         }
 
         \SimpleSAML\Logger::info(
             sprintf("deleted %s riak key%s", sizeof($result), sizeof($result) == 1 ? '' : 's')
         );
     } catch (\Exception $e) {
-        $message = 'riak threw exception: '.$e->getMessage();
+        $message = 'riak threw exception: ' . $e->getMessage();
         \SimpleSAML\Logger::warning($message);
         $croninfo['summary'][] = $message;
     }
