@@ -1,10 +1,9 @@
 <?php
-/* 
+/*
  * The configuration of SimpleSAMLphp sanitycheck package
  */
 
-$config = array (
-
+$config = [
     /*
      * Do you want to generate statistics using the cron module? If so, specify which cron tag to use.
      * Examples: daily, weekly
@@ -12,5 +11,4 @@ $config = array (
      *     'cron_tag' => null,
      */
     'cron_tag' => 'hourly',
-
-);
+];
