@@ -10,6 +10,8 @@ class SmartID extends \SimpleSAML\Auth\ProcessingFilter
      * IMPORTANT: If you use the (default) attributemaps (twitter2name, facebook2name,
      * etc., be sure to comment out the entries that map xxx_targetedID to
      * eduPersonTargetedID, or there will be no way to see its origin any more.
+     *
+     * @var array
      */
     private $candidates = [
         'eduPersonTargetedID',
@@ -24,29 +26,29 @@ class SmartID extends \SimpleSAML\Auth\ProcessingFilter
     ];
 
     /**
-     * The name of the generated ID attribute.
+     * @var string The name of the generated ID attribute.
      */
     private $id_attribute = 'smart_id';
 
     /**
      * Whether to append the AuthenticatingAuthority, separated by '!'
      * This only works when SSP is used as a gateway.
+     * @var bool
      */
     private $add_authority = true;
 
     /**
      * Whether to prepend the CandidateID, separated by ':'
+     * @var bool
      */
     private $add_candidate = true;
 
+
     /**
-     * Attributes which should be added/appended.
-     *
-     * Associative array of arrays.
+     * @param array $config
+     * @param mixed $reserved
+     * @throws \Exception
      */
-    private $attributes = [];
-
-
     public function __construct($config, $reserved)
     {
         parent::__construct($config, $reserved);
@@ -82,34 +84,43 @@ class SmartID extends \SimpleSAML\Auth\ProcessingFilter
         }
     }
 
+
+    /**
+     * @param array $attributes
+     * @param array $request
+     * @return string
+     * @throws \SimpleSAML\Error\Exception
+     */
     private function addID($attributes, $request)
     {
         $state = $request['saml:sp:State'];
         foreach ($this->candidates as $idCandidate) {
             if (isset($attributes[$idCandidate][0])) {
                 if (($this->add_authority) && (isset($state['saml:AuthenticatingAuthority'][0]))) {
-                    return ($this->add_candidate ? $idCandidate.':' : '').$attributes[$idCandidate][0].'!'.
+                    return ($this->add_candidate ? $idCandidate . ':' : '') . $attributes[$idCandidate][0] . '!' .
                         $state['saml:AuthenticatingAuthority'][0];
                 } else {
-                    return ($this->add_candidate ? $idCandidate.':' : '').$attributes[$idCandidate][0];
+                    return ($this->add_candidate ? $idCandidate . ':' : '') . $attributes[$idCandidate][0];
                 }
             }
         }
         /*
          * At this stage no usable id_candidate has been detected.
          */
-        throw new \SimpleSAML\Error\Exception('This service needs at least one of the following
-            attributes to identity users: '.implode(', ', $this->candidates).'. Unfortunately not
-            one of them was detected. Please ask your institution administrator to release one of
-            them, or try using another identity provider.');
+        throw new \SimpleSAML\Error\Exception('This service needs at least one of the following ' .
+            'attributes to identity users: '.implode(', ', $this->candidates).'. Unfortunately not '.
+            'one of them was detected. Please ask your institution administrator to release one of '.
+            'them, or try using another identity provider.');
     }
 
+
     /**
      * Apply filter to add or replace attributes.
      *
      * Add or replace existing attributes with the configured values.
      *
      * @param array &$request  The current request
+     * @return void
      */
     public function process(&$request)
     {
@@ -118,7 +129,7 @@ class SmartID extends \SimpleSAML\Auth\ProcessingFilter
 
         $id = $this->addID($request['Attributes'], $request);
 
-        if (isset($id)) {
+        if (!empty($id)) {
             $request['Attributes'][$this->id_attribute] = [$id];
         }
     }
