@@ -2,13 +2,32 @@
 
 namespace SimpleSAML\Module\statistics;
 
-/*
+use SimpleSAML\Configuration;
+
+/**
  * @author Andreas Åkre Solberg <andreas.solberg@uninett.no>
  * @package SimpleSAMLphp
  */
-
 class RatioDataset extends StatDataset
 {
+    /**
+     * Constructor
+     *
+     * @param \SimpleSAML\Configuration $statconfig
+     * @param \SimpleSAML\Configuration $ruleconfig
+     * @param string $ruleid
+     * @param string $timeres
+     * @param int $fileslot
+     */
+    public function __construct(Configuration $statconfig, Configuration $ruleconfig, $ruleid, $timeres, $fileslot)
+    {
+        parent::__construct($statconfig, $ruleconfig, $ruleid, $timeres, $fileslot);
+    }
+
+
+    /**
+     * @return void
+     */
     public function aggregateSummary()
     {
         /**
@@ -42,7 +61,13 @@ class RatioDataset extends StatDataset
         $this->summary = array_reverse($this->summary, true);
     }
 
-    private function ag($k, $a)
+
+    /**
+     * @param string $k
+     * @param array $a
+     * @return int
+     */
+    private function ag($k, array $a)
     {
         if (array_key_exists($k, $a)) {
             return $a[$k];
@@ -50,6 +75,12 @@ class RatioDataset extends StatDataset
         return 0;
     }
 
+
+    /**
+     * @param int $v1
+     * @param int $v2
+     * @return int|float
+     */
     private function divide($v1, $v2)
     {
         if ($v2 == 0) {
@@ -58,7 +89,13 @@ class RatioDataset extends StatDataset
         return ($v1 / $v2);
     }
 
-    public function combine($result1, $result2)
+
+    /**
+     * @param array $result1
+     * @param array $result2
+     * @return array
+     */
+    public function combine(array $result1, array $result2)
     {
         $combined = [];
 
@@ -74,8 +111,12 @@ class RatioDataset extends StatDataset
         return $combined;
     }
 
+
+    /**
+     * @return array
+     */
     public function getPieData()
     {
-        return null;
+        return [];
     }
 }
