@@ -2,27 +2,42 @@
 
 namespace SimpleSAML\Module\statistics;
 
-/*
+use SimpleSAML\Configuration;
+
+/**
  * @author Andreas Åkre Solberg <andreas.solberg@uninett.no>
  * @package SimpleSAMLphp
  */
-
 class Ruleset
 {
+    /** \SimpleSAML\Configuration */
     private $statconfig;
+
+    /** @var array */
     private $availrulenames;
+
+    /** @var array */
     private $availrules;
+
+    /** @var array */
     private $available;
 
+
     /**
      * Constructor
+     *
+     * @param \SimpleSAML\Configuration $statconfig
      */
-    public function __construct($statconfig)
+    public function __construct(Configuration $statconfig)
     {
         $this->statconfig = $statconfig;
         $this->init();
     }
 
+
+    /**
+     * @return void
+     */
     private function init()
     {
         $statdir = $this->statconfig->getValue('statdir');
@@ -33,7 +48,7 @@ class Ruleset
          * Walk through file lists, and get available [rule][fileslot]...
          */
         if (!is_dir($statdir)) {
-            throw new \Exception('Statisics output directory ['.$statdir.'] does not exists.');
+            throw new \Exception('Statisics output directory [' . $statdir . '] does not exist.');
         }
         $filelist = scandir($statdir);
         $this->available = [];
@@ -47,10 +62,10 @@ class Ruleset
             }
         }
         if (empty($this->available)) {
-            throw new \Exception('No aggregated statistics files found in ['.$statdir.']');
+            throw new \Exception('No aggregated statistics files found in [' . $statdir . ']');
         }
 
-        /*
+        /**
          * Create array with information about available rules..
          */
         $this->availrules = array_keys($statrules);
@@ -61,18 +76,30 @@ class Ruleset
         $this->availrulenames = $available_rules;
     }
 
+
+    /**
+     * @return array
+     */
     public function availableRules()
     {
         return $this->availrules;
     }
 
+
+    /**
+     * @return array
+     */
     public function availableRulesNames()
     {
         return $this->availrulenames;
     }
 
+
     /**
      * Resolve which rule is selected. Taking user preference and checks if it exists.
+     *
+     * @param string|null $preferRule
+     * @return string|null
      */
     private function resolveSelectedRule($preferRule = null)
     {
@@ -85,7 +112,12 @@ class Ruleset
         return $rule;
     }
 
-    public function getRule($preferRule)
+
+    /**
+     * @param string|null $preferRule
+     * @return \SimpleSAML\Module\statistics\Statistics\Rulesets\BaseRule
+     */
+    public function getRule($preferRule = null)
     {
         $rule = $this->resolveSelectedRule($preferRule);
         $statrulesConfig = $this->statconfig->getConfigItem('statrules');
@@ -95,7 +127,11 @@ class Ruleset
             $statruleConfig->getValue('presenter', 'statistics:BaseRule'),
             'Statistics\Rulesets'
         );
+
+        /** @psalm-suppress InvalidStringClass */
         $statrule = new $presenterClass($this->statconfig, $statruleConfig, $rule, $this->available);
+
+        /** @var \SimpleSAML\Module\statistics\Statistics\Rulesets\BaseRule $statrule */
         return $statrule;
     }
 }
