@@ -2,40 +2,62 @@
 
 namespace SimpleSAML\Module\statistics\Statistics\Rulesets;
 
-/*
+use SimpleSAML\Configuration;
+use SimpleSAML\Module\statistics\DateHandler;
+use SimpleSAML\Module\statistics\DateHandlerMonth;
+use SimpleSAML\Module\statistics\StatDataset;
+
+/**
  * @author Andreas Åkre Solberg <andreas.solberg@uninett.no>
  * @package SimpleSAMLphp
  */
-
 class BaseRule
 {
+    /** @var \SimpleSAML\Configuration */
     protected $statconfig;
+
+    /** @var \SimpleSAML\Configuration */
     protected $ruleconfig;
-    protected $ruleid;
-    protected $available;
+
+    /** @var string */
+    protected $ruleid = '';
+
+    /** @var array */
+    protected $available = [];
+
 
     /**
      * Constructor
+     *
+     * @param \SimpleSAML\Configuration $statconfig
+     * @param \SimpleSAML\Configuration $ruleconfig
+     * @param string $ruleid
+     * @param array $available
      */
-    public function __construct($statconfig, $ruleconfig, $ruleid, $available)
+    public function __construct(Configuration $statconfig, Configuration $ruleconfig, $ruleid, array $available)
     {
-        assert($statconfig instanceof \SimpleSAML\Configuration);
-        assert($ruleconfig instanceof \SimpleSAML\Configuration);
         $this->statconfig = $statconfig;
         $this->ruleconfig = $ruleconfig;
         $this->ruleid = $ruleid;
 
-        $this->available = null;
         if (array_key_exists($ruleid, $available)) {
             $this->available = $available[$ruleid];
         }
     }
 
+
+    /**
+     * @return string
+     */
     public function getRuleID()
     {
         return $this->ruleid;
     }
 
+
+    /**
+     * @return array
+     */
     public function availableTimeRes()
     {
         $timeresConfigs = $this->statconfig->getValue('timeres');
@@ -48,15 +70,20 @@ class BaseRule
         return $available_times;
     }
 
+
+    /**
+     * @param string $timeres
+     * @return array
+     */
     public function availableFileSlots($timeres)
     {
         $timeresConfigs = $this->statconfig->getValue('timeres');
         $timeresConfig = $timeresConfigs[$timeres];
 
         if (isset($timeresConfig['customDateHandler']) && $timeresConfig['customDateHandler'] == 'month') {
-            $datehandler = new \SimpleSAML\Module\statistics\DateHandlerMonth(0);
+            $datehandler = new DateHandlerMonth(0);
         } else {
-            $datehandler = new \SimpleSAML\Module\statistics\DateHandler($this->statconfig->getValue('offset', 0));
+            $datehandler = new DateHandler($this->statconfig->getValue('offset', 0));
         }
 
         /*
@@ -74,6 +101,11 @@ class BaseRule
         return $available_times;
     }
 
+
+    /**
+     * @param string $preferTimeRes
+     * @return string
+     */
     protected function resolveTimeRes($preferTimeRes)
     {
         $timeresavailable = array_keys($this->available);
@@ -86,6 +118,12 @@ class BaseRule
         return $timeres;
     }
 
+
+    /**
+     * @param string $timeres
+     * @param string $preferTime
+     * @return int
+     */
     protected function resolveFileSlot($timeres, $preferTime)
     {
         // Get which time (fileslot) to use.. First get a default, which is the most recent one.
@@ -97,6 +135,12 @@ class BaseRule
         return $fileslot;
     }
 
+
+    /**
+     * @param string $timeres
+     * @param string $preferTime
+     * @return array
+     */
     public function getTimeNavigation($timeres, $preferTime)
     {
         $fileslot = $this->resolveFileSlot($timeres, $preferTime);
@@ -118,11 +162,17 @@ class BaseRule
         return ['prev' => $available_times_prev, 'next' => $available_times_next];
     }
 
+
+    /**
+     * @param string $preferTimeRes
+     * @param string $preferTime
+     * @return \SimpleSAML\Module\statistics\StatDataset
+     */
     public function getDataSet($preferTimeRes, $preferTime)
     {
         $timeres = $this->resolveTimeRes($preferTimeRes);
         $fileslot = $this->resolveFileSlot($timeres, $preferTime);
-        $dataset = new \SimpleSAML\Module\statistics\StatDataset(
+        $dataset = new StatDataset(
             $this->statconfig,
             $this->ruleconfig,
             $this->ruleid,
