@@ -1,8 +1,12 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test;
 
+use Exception;
 use PHPUnit\Framework\TestCase;
+use SimpleSAML\Configuration;
 use SimpleSAML\Module;
 
 class ModuleTest extends TestCase
@@ -11,7 +15,7 @@ class ModuleTest extends TestCase
      * Test for SimpleSAML\Module::isModuleEnabled().
      * @return void
      */
-    public function testIsModuleEnabled()
+    public function testIsModuleEnabled(): void
     {
         // test for the most basic functionality
         $this->assertTrue(Module::isModuleEnabled('core'));
@@ -22,7 +26,7 @@ class ModuleTest extends TestCase
      * Test for SimpleSAML\Module::getModuleDir().
      * @return void
      */
-    public function testGetModuleDir()
+    public function testGetModuleDir(): void
     {
         // test for the most basic functionality
         $this->assertEquals(
@@ -36,9 +40,9 @@ class ModuleTest extends TestCase
      * Test for SimpleSAML\Module::getModuleURL().
      * @return void
      */
-    public function testGetModuleURL()
+    public function testGetModuleURL(): void
     {
-        \SimpleSAML\Configuration::loadFromArray([
+        Configuration::loadFromArray([
             'baseurlpath' => 'https://example.com/simplesaml/'
         ], '', 'simplesaml');
         $this->assertEquals(
@@ -59,7 +63,7 @@ class ModuleTest extends TestCase
      * Test for SimpleSAML\Module::getModules().
      * @return void
      */
-    public function testGetModules()
+    public function testGetModules(): void
     {
         $this->assertGreaterThan(0, count(Module::getModules()));
     }
@@ -71,9 +75,9 @@ class ModuleTest extends TestCase
      * class).
      * @return void
      */
-    public function testResolveClassNoModule()
+    public function testResolveClassNoModule(): void
     {
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
         Module::resolveClass('nomodule', '');
     }
 
@@ -83,9 +87,9 @@ class ModuleTest extends TestCase
      * asking for cannot be found.
      * @return void
      */
-    public function testResolveClassNotFound()
+    public function testResolveClassNotFound(): void
     {
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
         Module::resolveClass('core:Missing', '');
     }
 
@@ -95,9 +99,9 @@ class ModuleTest extends TestCase
      * asking for can be resolved, but does not extend a given class.
      * @return void
      */
-    public function testResolveClassNotSubclass()
+    public function testResolveClassNotSubclass(): void
     {
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
         Module::resolveClass('core:PHP', 'Auth_Process', '\Exception');
     }
 
@@ -106,19 +110,19 @@ class ModuleTest extends TestCase
      * Test for SimpleSAML\Module::resolveClass(). It covers all the valid use cases.
      * @return void
      */
-    public function tesstResolveClass()
+    public function testResolveClass(): void
     {
         // most basic test
-        $this->assertEquals('sspmod_core_ACL', Module::resolveClass('core:ACL', ''));
+        $this->assertEquals('SimpleSAML\Module\cron\Cron', Module::resolveClass('cron:Cron', ''));
 
         // test for the $type parameter correctly translated into a path
         $this->assertEquals(
-            '\SimpleSAML\Module\core\Auth\Process\PHP',
-            Module::resolveClass('core:PHP', 'Auth_Process')
+            'SimpleSAML\Module\core\Auth\Process\PHP',
+            Module::resolveClass('core:PHP', 'Auth\Process')
         );
 
         // test for valid subclasses
-        $this->assertEquals('\SimpleSAML\Module\core\Auth\Process\PHP', Module::resolveClass(
+        $this->assertEquals('SimpleSAML\Module\core\Auth\Process\PHP', Module::resolveClass(
             'core:PHP',
             'Auth\Process',
             '\SimpleSAML\Auth\ProcessingFilter'
