@@ -1,9 +1,12 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test\Store;
 
 use PHPUnit\Framework\TestCase;
 use Predis\Client;
+use ReflectionClass;
 use SimpleSAML\Configuration;
 use SimpleSAML\Store;
 
@@ -70,9 +73,9 @@ class RedisTest extends TestCase
 
     /**
      * @param string $key
-     * @return \Predis\Client
+     * @return string|null
      */
-    public function getMocked($key)
+    public function getMocked(string $key): ?string
     {
         return array_key_exists($key, $this->config) ? $this->config[$key] : null;
     }
@@ -83,7 +86,7 @@ class RedisTest extends TestCase
      * @param mixed $value
      * @return void
      */
-    public function setMocked($key, $value)
+    public function setMocked(string $key, $value): void
     {
         $this->config[$key] = $value;
     }
@@ -95,7 +98,7 @@ class RedisTest extends TestCase
      * @param mixed $value
      * @return void
      */
-    public function setexMocked($key, $expire, $value)
+    public function setexMocked(string $key, int $expire, $value): void
     {
         // Testing expiring data is more trouble than it's worth for now
         $this->setMocked($key, $value);
@@ -106,7 +109,7 @@ class RedisTest extends TestCase
      * @param string $key
      * @return void
      */
-    public function delMocked($key)
+    public function delMocked(string $key): void
     {
         unset($this->config[$key]);
     }
@@ -118,7 +121,7 @@ class RedisTest extends TestCase
      * @test
      * @return void
      */
-    public function testRedisInstance()
+    public function testRedisInstance(): void
     {
         $config = Configuration::loadFromArray([
             'store.type' => 'redis',
@@ -141,7 +144,7 @@ class RedisTest extends TestCase
      * @test
      * @return void
      */
-    public function testRedisInstanceWithPassword()
+    public function testRedisInstanceWithPassword(): void
     {
         $config = Configuration::loadFromArray([
             'store.type' => 'redis',
@@ -165,7 +168,7 @@ class RedisTest extends TestCase
      * @test
      * @return void
      */
-    public function testInsertData()
+    public function testInsertData(): void
     {
         $value = 'TEST';
 
@@ -183,7 +186,7 @@ class RedisTest extends TestCase
      * @test
      * @return void
      */
-    public function testInsertExpiringData()
+    public function testInsertExpiringData(): void
     {
         $value = 'TEST';
 
@@ -200,7 +203,7 @@ class RedisTest extends TestCase
      * @test
      * @return void
      */
-    public function testGetEmptyData()
+    public function testGetEmptyData(): void
     {
         $res = $this->redis->get('test', 'key');
 
@@ -214,7 +217,7 @@ class RedisTest extends TestCase
      * @test
      * @return void
      */
-    public function testOverwriteData()
+    public function testOverwriteData(): void
     {
         $value1 = 'TEST1';
         $value2 = 'TEST2';
@@ -235,7 +238,7 @@ class RedisTest extends TestCase
      * @test
      * @return void
      */
-    public function testDeleteData()
+    public function testDeleteData(): void
     {
         $this->redis->set('test', 'key', 'TEST');
         $this->redis->delete('test', 'key');
@@ -247,12 +250,12 @@ class RedisTest extends TestCase
 
     /**
      * @param \SimpleSAML\Configuration|\SimpleSAML\Store $service
-     * @param string $className
+     * @param class-string $className
      * @return void
      */
-    protected function clearInstance($service, $className)
+    protected function clearInstance($service, string $className): void
     {
-        $reflectedClass = new \ReflectionClass($className);
+        $reflectedClass = new ReflectionClass($className);
         $reflectedInstance = $reflectedClass->getProperty('instance');
         $reflectedInstance->setAccessible(true);
         $reflectedInstance->setValue($service, null);
