@@ -1,8 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test;
 
 use PHPUnit\Framework\TestCase;
+use ReflectionClass;
 use SimpleSAML\Configuration;
 use SimpleSAML\Error\CriticalConfigurationError;
 use SimpleSAML\Store;
@@ -23,7 +26,7 @@ class StoreTest extends TestCase
      * @test
      * @return void
      */
-    public function defaultStore()
+    public function defaultStore(): void
     {
         Configuration::loadFromArray([], '[ARRAY]', 'simplesaml');
 
@@ -39,7 +42,7 @@ class StoreTest extends TestCase
      * @test
      * @return void
      */
-    public function phpSessionStore()
+    public function phpSessionStore(): void
     {
         Configuration::loadFromArray([], '[ARRAY]', 'simplesaml');
 
@@ -55,7 +58,7 @@ class StoreTest extends TestCase
      * @test
      * @return void
      */
-    public function memcacheStore()
+    public function memcacheStore(): void
     {
         Configuration::loadFromArray([
             'store.type'                    => 'memcache',
@@ -72,7 +75,7 @@ class StoreTest extends TestCase
      * @test
      * @return void
      */
-    public function sqlStore()
+    public function sqlStore(): void
     {
         Configuration::loadFromArray([
             'store.type'                    => 'sql',
@@ -91,7 +94,7 @@ class StoreTest extends TestCase
      * @test
      * @return void
      */
-    public function pathStore()
+    public function pathStore(): void
     {
         Configuration::loadFromArray([
             'store.type'                    => '\SimpleSAML\Store\SQL',
@@ -110,7 +113,7 @@ class StoreTest extends TestCase
      * @test
      * @return void
      */
-    public function notFoundStoreException()
+    public function notFoundStoreException(): void
     {
         $this->expectException(CriticalConfigurationError::class);
         Configuration::loadFromArray([
@@ -139,12 +142,12 @@ class StoreTest extends TestCase
 
     /**
      * @param \SimpleSAML\Configuration|\SimpleSAML\Store $service
-     * @param string $className
+     * @param class-string $className
      * @return void
      */
-    protected function clearInstance($service, $className)
+    protected function clearInstance($service, string $className): void
     {
-        $reflectedClass = new \ReflectionClass($className);
+        $reflectedClass = new ReflectionClass($className);
         $reflectedInstance = $reflectedClass->getProperty('instance');
         $reflectedInstance->setAccessible(true);
         $reflectedInstance->setValue($service, null);
