@@ -1,9 +1,15 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test\Utils\Config;
 
+use DOMDocument;
+use InvalidArgumentException;
 use PHPUnit\Framework\TestCase;
+use SAML2\Constants;
 use SimpleSAML\Utils\Config\Metadata;
+use TypeError;
 
 /**
  * Tests related to SAML metadata.
@@ -14,7 +20,7 @@ class MetadataTest extends TestCase
      * Test contact configuration parsing and sanitizing.
      * @return void
      */
-    public function testGetContact()
+    public function testGetContact(): void
     {
         // test invalid argument
         try {
@@ -30,7 +36,7 @@ class MetadataTest extends TestCase
         ];
         try {
             Metadata::getContact($contact);
-        } catch (\InvalidArgumentException $e) {
+        } catch (InvalidArgumentException $e) {
             $this->assertStringStartsWith('"contactType" is mandatory and must be one of ', $e->getMessage());
         }
 
@@ -40,7 +46,7 @@ class MetadataTest extends TestCase
         ];
         try {
             Metadata::getContact($contact);
-        } catch (\InvalidArgumentException $e) {
+        } catch (InvalidArgumentException $e) {
             $this->assertStringStartsWith('"contactType" is mandatory and must be one of ', $e->getMessage());
         }
 
@@ -110,7 +116,7 @@ class MetadataTest extends TestCase
             $contact['givenName'] = $type;
             try {
                 Metadata::getContact($contact);
-            } catch (\InvalidArgumentException $e) {
+            } catch (InvalidArgumentException $e) {
                 $this->assertEquals('"givenName" must be a string and cannot be empty.', $e->getMessage());
             }
         }
@@ -124,7 +130,7 @@ class MetadataTest extends TestCase
             $contact['surName'] = $type;
             try {
                 Metadata::getContact($contact);
-            } catch (\InvalidArgumentException $e) {
+            } catch (InvalidArgumentException $e) {
                 $this->assertEquals('"surName" must be a string and cannot be empty.', $e->getMessage());
             }
         }
@@ -138,7 +144,7 @@ class MetadataTest extends TestCase
             $contact['company'] = $type;
             try {
                 Metadata::getContact($contact);
-            } catch (\InvalidArgumentException $e) {
+            } catch (InvalidArgumentException $e) {
                 $this->assertEquals('"company" must be a string and cannot be empty.', $e->getMessage());
             }
         }
@@ -152,7 +158,7 @@ class MetadataTest extends TestCase
             $contact['emailAddress'] = $type;
             try {
                 Metadata::getContact($contact);
-            } catch (\InvalidArgumentException $e) {
+            } catch (InvalidArgumentException $e) {
                 $this->assertEquals(
                     '"emailAddress" must be a string or an array and cannot be empty.',
                     $e->getMessage()
@@ -164,7 +170,7 @@ class MetadataTest extends TestCase
             $contact['emailAddress'] = $type;
             try {
                 Metadata::getContact($contact);
-            } catch (\InvalidArgumentException $e) {
+            } catch (InvalidArgumentException $e) {
                 $this->assertEquals(
                     'Email addresses must be a string and cannot be empty.',
                     $e->getMessage()
@@ -187,7 +193,7 @@ class MetadataTest extends TestCase
             $contact['telephoneNumber'] = $type;
             try {
                 Metadata::getContact($contact);
-            } catch (\InvalidArgumentException $e) {
+            } catch (InvalidArgumentException $e) {
                 $this->assertEquals(
                     '"telephoneNumber" must be a string or an array and cannot be empty.',
                     $e->getMessage()
@@ -199,7 +205,7 @@ class MetadataTest extends TestCase
             $contact['telephoneNumber'] = $type;
             try {
                 Metadata::getContact($contact);
-            } catch (\InvalidArgumentException $e) {
+            } catch (InvalidArgumentException $e) {
                 $this->assertEquals('Telephone numbers must be a string and cannot be empty.', $e->getMessage());
             }
         }
@@ -230,7 +236,7 @@ class MetadataTest extends TestCase
      * Test \SimpleSAML\Utils\Config\Metadata::isHiddenFromDiscovery().
      * @return void
      */
-    public function testIsHiddenFromDiscovery()
+    public function testIsHiddenFromDiscovery(): void
     {
         // test for success
         $metadata = [
@@ -242,8 +248,17 @@ class MetadataTest extends TestCase
         ];
         $this->assertTrue(Metadata::isHiddenFromDiscovery($metadata));
 
+        // test for failure
+        $this->assertFalse(Metadata::isHiddenFromDiscovery([
+            'EntityAttributes' => [
+                Metadata::$ENTITY_CATEGORY => [],
+            ],
+        ]));
+
         // test for failures
-        $this->assertFalse(Metadata::isHiddenFromDiscovery(['foo']));
+        $this->expectException(TypeError::class);
+        Metadata::isHiddenFromDiscovery(['foo']);
+
         $this->assertFalse(Metadata::isHiddenFromDiscovery([
             'EntityAttributes' => 'bar',
         ]));
@@ -255,24 +270,19 @@ class MetadataTest extends TestCase
                 Metadata::$ENTITY_CATEGORY => '',
             ],
         ]));
-        $this->assertFalse(Metadata::isHiddenFromDiscovery([
-            'EntityAttributes' => [
-                Metadata::$ENTITY_CATEGORY => [],
-            ],
-        ]));
     }
 
-    
+
     /**
      * Test \SimpleSAML\Utils\Config\Metadata::parseNameIdPolicy().
      * @return void
      */
-    public function testParseNameIdPolicy()
+    public function testParseNameIdPolicy(): void
     {
         // Test null or unset
         $nameIdPolicy = null;
         $this->assertEquals(
-            ['Format' => \SAML2\Constants::NAMEID_TRANSIENT, 'AllowCreate' => true],
+            ['Format' => Constants::NAMEID_TRANSIENT, 'AllowCreate' => true],
             Metadata::parseNameIdPolicy($nameIdPolicy)
         );
 
