@@ -1,11 +1,15 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test\Utils;
 
 use PHPUnit\Framework\TestCase;
+use SimpleSAML\Configuration;
+use SimpleSAML\Error;
 use SimpleSAML\Test\Utils\ClearStateTestCase;
 use SimpleSAML\Utils\HTTP;
-use SimpleSAML\Configuration;
+use Webmozart\Assert\Assert;
 
 class HTTPTest extends ClearStateTestCase
 {
@@ -15,12 +19,17 @@ class HTTPTest extends ClearStateTestCase
      * @param string $url The URL to use as the current one.
      * @return void
      */
-    private function setupEnvFromURL($url)
+    private function setupEnvFromURL(string $url): void
     {
-        $addr = parse_url($url);
-        $_SERVER['HTTP_HOST'] = $addr['host'];
-        $_SERVER['SERVER_NAME'] = $addr['host'];
-        if ($addr['scheme'] === 'https') {
+        $scheme = parse_url($url, PHP_URL_SCHEME);
+        $host = parse_url($url, PHP_URL_HOST);
+        $port = parse_url($url, PHP_URL_PORT);
+        $path = parse_url($url, PHP_URL_PATH);
+        $query = parse_url($url, PHP_URL_QUERY);
+
+        $_SERVER['HTTP_HOST'] = $host;
+        $_SERVER['SERVER_NAME'] = $host;
+        if ($scheme === 'https') {
             $_SERVER['HTTPS'] = 'on';
             $default_port = '443';
         } else {
@@ -28,10 +37,10 @@ class HTTPTest extends ClearStateTestCase
             $default_port = '80';
         }
         $_SERVER['SERVER_PORT'] = $default_port;
-        if (isset($addr['port']) && strval($addr['port']) !== $default_port) {
-            $_SERVER['SERVER_PORT'] = strval($addr['port']);
+        if (isset($port) && strval($port) !== $default_port) {
+            $_SERVER['SERVER_PORT'] = strval($port);
         }
-        $_SERVER['REQUEST_URI'] = $addr['path'] . '?' . $addr['query'];
+        $_SERVER['REQUEST_URI'] = $path . '?' . $query;
     }
 
 
@@ -65,7 +74,7 @@ class HTTPTest extends ClearStateTestCase
      * Test SimpleSAML\Utils\HTTP::addURLParameters().
      * @return void
      */
-    public function testAddURLParameters()
+    public function testAddURLParameters(): void
     {
         $url = 'http://example.com/';
         $params = [
@@ -93,7 +102,7 @@ class HTTPTest extends ClearStateTestCase
      * Test SimpleSAML\Utils\HTTP::guessBasePath().
      * @return void
      */
-    public function testGuessBasePath()
+    public function testGuessBasePath(): void
     {
         $original = $_SERVER;
 
@@ -137,7 +146,7 @@ class HTTPTest extends ClearStateTestCase
      * Test SimpleSAML\Utils\HTTP::getSelfHost() with and without custom port.
      * @return void
      */
-    public function testGetSelfHost()
+    public function testGetSelfHost(): void
     {
         $original = $_SERVER;
 
@@ -157,7 +166,7 @@ class HTTPTest extends ClearStateTestCase
      * Test SimpleSAML\Utils\HTTP::getSelfHostWithPort(), with and without custom port.
      * @return void
      */
-    public function testGetSelfHostWithPort()
+    public function testGetSelfHostWithPort(): void
     {
         $original = $_SERVER;
 
@@ -186,7 +195,7 @@ class HTTPTest extends ClearStateTestCase
      * Test SimpleSAML\Utils\HTTP::getSelfURL().
      * @return void
      */
-    public function testGetSelfURLMethods()
+    public function testGetSelfURLMethods(): void
     {
         $original = $_SERVER;
 
@@ -313,7 +322,7 @@ class HTTPTest extends ClearStateTestCase
      * Test SimpleSAML\Utils\HTTP::checkURLAllowed(), without regex.
      * @return void
      */
-    public function testCheckURLAllowedWithoutRegex()
+    public function testCheckURLAllowedWithoutRegex(): void
     {
         $original = $_SERVER;
 
@@ -345,7 +354,7 @@ class HTTPTest extends ClearStateTestCase
      * Test SimpleSAML\Utils\HTTP::checkURLAllowed(), with regex.
      * @return void
      */
-    public function testCheckURLAllowedWithRegex()
+    public function testCheckURLAllowedWithRegex(): void
     {
         $original = $_SERVER;
 
@@ -379,7 +388,7 @@ class HTTPTest extends ClearStateTestCase
      * Test SimpleSAML\Utils\HTTP::getServerPort().
      * @return void
      */
-    public function testGetServerPort()
+    public function testGetServerPort(): void
     {
         $original = $_SERVER;
 
@@ -426,7 +435,7 @@ class HTTPTest extends ClearStateTestCase
      * subdomain of an evil domain.
      * @return void
      */
-    public function testCheckURLAllowedWithRegexWithoutDelimiters()
+    public function testCheckURLAllowedWithRegexWithoutDelimiters(): void
     {
         $original = $_SERVER;
 
@@ -437,7 +446,7 @@ class HTTPTest extends ClearStateTestCase
 
         $_SERVER['REQUEST_URI'] = '/module.php';
 
-        $this->expectException(\SimpleSAML\Error\Exception::class);
+        $this->expectException(Error\Exception::class);
         HTTP::checkURLAllowed('https://app.example.com.evil.com');
 
         $_SERVER = $original;
@@ -448,7 +457,7 @@ class HTTPTest extends ClearStateTestCase
      * @covers SimpleSAML\Utils\HTTP::getFirstPathElement()
      * @return void
      */
-    public function testGetFirstPathElement()
+    public function testGetFirstPathElement(): void
     {
         $original = $_SERVER;
         $_SERVER['SCRIPT_NAME'] = '/test/tmp.php';
@@ -457,13 +466,14 @@ class HTTPTest extends ClearStateTestCase
         $_SERVER = $original;
     }
 
+
     /**
      * @covers SimpleSAML\Utils\HTTP::setCookie()
      * @runInSeparateProcess
      * @requires extension xdebug
      * @return void
      */
-    public function testSetCookie()
+    public function testSetCookie(): void
     {
         $original = $_SERVER;
         Configuration::loadFromArray([
@@ -514,13 +524,14 @@ class HTTPTest extends ClearStateTestCase
         $_SERVER = $original;
     }
 
+
     /**
      * @covers SimpleSAML\Utils\HTTP::setCookie()
      * @return void
      */
-    public function testSetCookieInsecure()
+    public function testSetCookieInsecure(): void
     {
-        $this->expectException(\SimpleSAML\Error\CannotSetCookie::class);
+        $this->expectException(Error\CannotSetCookie::class);
 
         $original = $_SERVER;
         Configuration::loadFromArray([
@@ -534,13 +545,14 @@ class HTTPTest extends ClearStateTestCase
         $_SERVER = $original;
     }
 
+
     /**
      * @covers SimpleSAML\Utils\HTTP::setCookie()
      * @runInSeparateProcess
      * @requires extension xdebug
      * @return void
      */
-    public function testSetCookieSameSite()
+    public function testSetCookieSameSite(): void
     {
         HTTP::setCookie('SSNull', 'value', ['samesite' => null]);
         HTTP::setCookie('SSNone', 'value', ['samesite' => 'None']);
@@ -553,4 +565,57 @@ class HTTPTest extends ClearStateTestCase
         $this->assertRegExp('/\b[Ss]ame[Ss]ite=Lax(;|$)/', $headers[2]);
         $this->assertRegExp('/\b[Ss]ame[Ss]ite=Strict(;|$)/', $headers[3]);
     }
+
+    /**
+     * Test detecting if user agent supports None
+     * @dataProvider detectSameSiteProvider
+     * @param null|string $userAgent The user agent. Null means not set, like with CLI
+     * @param bool $supportsNone None can be set as a SameSite flag
+     */
+    public function testDetectSameSiteNoneBehavior(?string $userAgent, bool $supportsNone): void
+    {
+        if ($userAgent) {
+            $_SERVER['HTTP_USER_AGENT'] = $userAgent;
+        }
+        $this->assertEquals($supportsNone, HTTP::canSetSameSiteNone(), $userAgent ?? 'No user agent set');
+    }
+
+    public function detectSameSiteProvider(): array
+    {
+        // @codingStandardsIgnoreStart
+        return [
+          [null, true],
+          ['some-new-browser', true],
+            //Browsers that can handle 'None'
+            // Chrome
+            ['Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.70 Safari/537.36', true],
+            // Chome on windows
+            ['Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36', true],
+            // Chrome linux
+            ['Mozilla/5.0 (X11; HasCodingOs 1.0; Linux x64) AppleWebKit/637.36 (KHTML, like Gecko) Chrome/70.0.3112.101 Safari/637.36 HasBrowser/5.0', true],
+             // Safari iOS 13
+            ['Mozilla/5.0 (iPhone; CPU iPhone OS 13_0 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/11.2 Mobile/15E148 Safari/604.1', true],
+            // Mac OS X with support
+            ['Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.1 Safari/605.1.15', true],
+            // UC Browser with support
+            ['Mozilla/5.0 (Linux; U; Android 9; en-US; SM-A705FN Build/PPR1.180610.011) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/57.0.2987.108 UCBrowser/12.13.2.1208 Mobile Safari/537.36', true],
+            ['Mozilla/5.0 (Linux; U; Android 10; en-US; RMX2020 Build/QP1A.190711.020) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/57.0.2987.108 UCBrowser/12.13.5.1209 Mobile Safari/537.36', true],
+            // Embedded Mac with support
+            ['Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_4) AppleWebKit/605.1.15 (KHTML, like Gecko)', true],
+            // Browser without support
+            // Old Safari on mac
+            ['Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_5) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/12.1.1 Safari/605.1.15', false],
+            // Old Safari on iOS 12 (phone and ipad
+            ['Mozilla/5.0 (iPhone; CPU iPhone OS 12_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/12.1 Mobile/15E148 Safari/604.1', false],
+            ['Mozilla/5.0 (iPad; CPU OS 12_0 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/12.0 Mobile/16A5288q Safari/605.1.15', false],
+            // Chromium without support
+            ['Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/65.0.3325.181 Chrome/65.0.3325.181 Safari/537.36', false],
+            // UC Browser without support
+            ['Mozilla/5.0 (Linux; U; Android 8.1.0; zh-CN; EML-AL00 Build/HUAWEIEML-AL00) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/57.0.2987.108 baidu.sogo.uc.UCBrowser/11.9.4.974 UWS/2.13.1.48 Mobile Safari/537.36 AliApp(DingTalk/4.5.11) com.alibaba.android.rimet/10487439 Channel/227200 language/zh-CN', false],
+            ['Mozilla/5.0 (Linux; U; Android 7.1.1; en-US; CPH1723 Build/N6F26Q) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/57.0.2987.108 UCBrowser/12.13.0.1207 Mobile Safari/537.36', false],
+            // old embedded browser
+            ['Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_4) AppleWebKit/605.1.15 (KHTML, like Gecko)', false]
+        ];
+        // @codingStandardsIgnoreEnd
+    }
 }
