@@ -1,9 +1,18 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test\Utils;
 
+use DOMComment;
+use DOMDocument;
+use DOMElement;
+use DOMException;
+use DOMText;
+use InvalidArgumentException;
 use PHPUnit\Framework\TestCase;
 use SimpleSAML\Configuration;
+use SimpleSAML\Error;
 use SimpleSAML\Utils\XML;
 
 /**
@@ -11,20 +20,18 @@ use SimpleSAML\Utils\XML;
  */
 class XMLTest extends TestCase
 {
-    const FRAMEWORK = 'vendor/simplesamlphp/simplesamlphp-test-framework';
-    // Visibility on constants is supported from PHP 7.1 and up
-    // private const FRAMEWORK = 'vendor/simplesamlphp/simplesamlphp-test-framework';
+    private const FRAMEWORK = 'vendor/simplesamlphp/simplesamlphp-test-framework';
 
     /**
      * @covers \SimpleSAML\Utils\XML::isDOMNodeOfType
      * @test
      * @return void
      */
-    public function testIsDomNodeOfTypeBasic()
+    public function testIsDomNodeOfTypeBasic(): void
     {
         $name = 'name';
         $namespace_uri = 'ns';
-        $element = new \DOMElement($name, 'value', $namespace_uri);
+        $element = new DOMElement($name, 'value', $namespace_uri);
 
         $res = XML::isDOMNodeOfType($element, $name, $namespace_uri);
 
@@ -37,12 +44,12 @@ class XMLTest extends TestCase
      * @test
      * @return void
      */
-    public function testIsDomNodeOfTypeMissingNamespace()
+    public function testIsDomNodeOfTypeMissingNamespace(): void
     {
-        $this->expectException(\InvalidArgumentException::class);
+        $this->expectException(InvalidArgumentException::class);
         $name = 'name';
         $namespace_uri = '@missing';
-        $element = new \DOMElement($name, 'value', $namespace_uri);
+        $element = new DOMElement($name, 'value', $namespace_uri);
 
         XML::isDOMNodeOfType($element, $name, $namespace_uri);
     }
@@ -53,11 +60,11 @@ class XMLTest extends TestCase
      * @test
      * @return void
      */
-    public function testIsDomNodeOfTypeEmpty()
+    public function testIsDomNodeOfTypeEmpty(): void
     {
         $name = 'name';
         $namespace_uri = '';
-        $element = new \DOMElement($name);
+        $element = new DOMElement($name);
 
         $res = XML::isDOMNodeOfType($element, $name, $namespace_uri);
 
@@ -70,12 +77,12 @@ class XMLTest extends TestCase
      * @test
      * @return void
      */
-    public function testIsDomNodeOfTypeShortcut()
+    public function testIsDomNodeOfTypeShortcut(): void
     {
         $name = 'name';
         $namespace_uri = 'urn:oasis:names:tc:SAML:2.0:metadata';
         $short_namespace_uri = '@md';
-        $element = new \DOMElement($name, 'value', $namespace_uri);
+        $element = new DOMElement($name, 'value', $namespace_uri);
 
         $res = XML::isDOMNodeOfType($element, $name, $short_namespace_uri);
 
@@ -88,12 +95,12 @@ class XMLTest extends TestCase
      * @test
      * @return void
      */
-    public function testIsDomNodeOfTypeIncorrectName()
+    public function testIsDomNodeOfTypeIncorrectName(): void
     {
         $name = 'name';
         $bad_name = 'bad name';
         $namespace_uri = 'ns';
-        $element = new \DOMElement($name, 'value', $namespace_uri);
+        $element = new DOMElement($name, 'value', $namespace_uri);
 
         $res = XML::isDOMNodeOfType($element, $bad_name, $namespace_uri);
 
@@ -106,12 +113,12 @@ class XMLTest extends TestCase
      * @test
      * @return void
      */
-    public function testIsDomNodeOfTypeIncorrectNamespace()
+    public function testIsDomNodeOfTypeIncorrectNamespace(): void
     {
         $name = 'name';
         $namespace_uri = 'ns';
         $bad_namespace_uri = 'bad name';
-        $element = new \DOMElement($name, 'value', $namespace_uri);
+        $element = new DOMElement($name, 'value', $namespace_uri);
 
         $res = XML::isDOMNodeOfType($element, $name, $bad_namespace_uri);
 
@@ -124,12 +131,12 @@ class XMLTest extends TestCase
      * @test
      * @return void
      */
-    public function testGetDomTextBasic()
+    public function testGetDomTextBasic(): void
     {
         $data = 'root value';
-        $dom = new \DOMDocument();
+        $dom = new DOMDocument();
         $element = $dom->appendChild(new \DOMElement('root'));
-        $element->appendChild(new \DOMText($data));
+        $element->appendChild(new DOMText($data));
 
         $res = XML::getDOMText($element);
         $expected = $data;
@@ -143,14 +150,14 @@ class XMLTest extends TestCase
      * @test
      * @return void
      */
-    public function testGetDomTextMulti()
+    public function testGetDomTextMulti(): void
     {
         $data1 = 'root value 1';
         $data2 = 'root value 2';
-        $dom = new \DOMDocument();
-        $element = $dom->appendChild(new \DOMElement('root'));
-        $element->appendChild(new \DOMText($data1));
-        $element->appendChild(new \DOMText($data2));
+        $dom = new DOMDocument();
+        $element = $dom->appendChild(new DOMElement('root'));
+        $element->appendChild(new DOMText($data1));
+        $element->appendChild(new DOMText($data2));
 
         $res = XML::getDOMText($element);
         $expected = $data1 . $data2 . $data1 . $data2;
@@ -164,12 +171,12 @@ class XMLTest extends TestCase
      * @test
      * @return void
      */
-    public function testGetDomTextIncorrectType()
+    public function testGetDomTextIncorrectType(): void
     {
-        $this->expectException(\SimpleSAML\Error\Exception::class);
-        $dom = new \DOMDocument();
-        $element = $dom->appendChild(new \DOMElement('root'));
-        $element->appendChild(new \DOMComment(''));
+        $this->expectException(Error\Exception::class);
+        $dom = new DOMDocument();
+        $element = $dom->appendChild(new DOMElement('root'));
+        $element->appendChild(new DOMComment(''));
 
         XML::getDOMText($element);
     }
@@ -180,12 +187,12 @@ class XMLTest extends TestCase
      * @test
      * @return void
      */
-    public function testGetDomChildrenBasic()
+    public function testGetDomChildrenBasic(): void
     {
         $name = 'name';
         $namespace_uri = 'ns';
-        $dom = new \DOMDocument();
-        $element = new \DOMElement($name, 'value', $namespace_uri);
+        $dom = new DOMDocument();
+        $element = new DOMElement($name, 'value', $namespace_uri);
         $dom->appendChild($element);
 
         $res = XML::getDOMChildren($dom, $name, $namespace_uri);
@@ -200,11 +207,11 @@ class XMLTest extends TestCase
      * @test
      * @return void
      */
-    public function testGetDomChildrenIncorrectType()
+    public function testGetDomChildrenIncorrectType(): void
     {
-        $dom = new \DOMDocument();
-        $text = new \DOMText('text');
-        $comment = new \DOMComment('comment');
+        $dom = new DOMDocument();
+        $text = new DOMText('text');
+        $comment = new DOMComment('comment');
         $dom->appendChild($text);
         $dom->appendChild($comment);
 
@@ -219,13 +226,13 @@ class XMLTest extends TestCase
      * @test
      * @return void
      */
-    public function testGetDomChildrenIncorrectName()
+    public function testGetDomChildrenIncorrectName(): void
     {
         $name = 'name';
         $bad_name = 'bad name';
         $namespace_uri = 'ns';
-        $dom = new \DOMDocument();
-        $element = new \DOMElement($name, 'value', $namespace_uri);
+        $dom = new DOMDocument();
+        $element = new DOMElement($name, 'value', $namespace_uri);
         $dom->appendChild($element);
 
         $res = XML::getDOMChildren($dom, $bad_name, $namespace_uri);
@@ -239,10 +246,10 @@ class XMLTest extends TestCase
      * @test
      * @return void
      */
-    public function testFormatDomElementBasic()
+    public function testFormatDomElementBasic(): void
     {
-        $dom = new \DOMDocument();
-        $root = new \DOMElement('root');
+        $dom = new DOMDocument();
+        $root = new DOMElement('root');
         $dom->appendChild($root);
         $root->appendChild(new \DOMText('text'));
 
@@ -263,14 +270,14 @@ NOWDOC;
      * @test
      * @return void
      */
-    public function testFormatDomElementNested()
+    public function testFormatDomElementNested(): void
     {
-        $dom = new \DOMDocument();
-        $root = new \DOMElement('root');
-        $nested = new \DOMElement('nested');
+        $dom = new DOMDocument();
+        $root = new DOMElement('root');
+        $nested = new DOMElement('nested');
         $dom->appendChild($root);
         $root->appendChild($nested);
-        $nested->appendChild(new \DOMText('text'));
+        $nested->appendChild(new DOMText('text'));
 
         XML::formatDOMElement($root);
         $res = $dom->saveXML();
@@ -291,15 +298,15 @@ NOWDOC;
      * @test
      * @return void
      */
-    public function testFormatDomElementIndentBase()
+    public function testFormatDomElementIndentBase(): void
     {
         $indent_base = 'base';
-        $dom = new \DOMDocument();
-        $root = new \DOMElement('root');
-        $nested = new \DOMElement('nested');
+        $dom = new DOMDocument();
+        $root = new DOMElement('root');
+        $nested = new DOMElement('nested');
         $dom->appendChild($root);
         $root->appendChild($nested);
-        $nested->appendChild(new \DOMText('text'));
+        $nested->appendChild(new DOMText('text'));
 
         XML::formatDOMElement($root, $indent_base);
         $res = $dom->saveXML();
@@ -320,13 +327,13 @@ HEREDOC;
      * @test
      * @return void
      */
-    public function testFormatDomElementTextAndChild()
+    public function testFormatDomElementTextAndChild(): void
     {
-        $dom = new \DOMDocument();
-        $root = new \DOMElement('root');
+        $dom = new DOMDocument();
+        $root = new DOMElement('root');
         $dom->appendChild($root);
-        $root->appendChild(new \DOMText('text'));
-        $root->appendChild(new \DOMElement('child'));
+        $root->appendChild(new DOMText('text'));
+        $root->appendChild(new DOMElement('child'));
 
         XML::formatDOMElement($root);
         $res = $dom->saveXML();
@@ -345,7 +352,7 @@ HEREDOC;
      * @test
      * @return void
      */
-    public function testFormatXmlStringBasic()
+    public function testFormatXmlStringBasic(): void
     {
         $xml = '<root><nested>text</nested></root>';
 
@@ -365,9 +372,9 @@ NOWDOC;
      * @test
      * @return void
      */
-    public function testFormatXmlStringMalformedXml()
+    public function testFormatXmlStringMalformedXml(): void
     {
-        $this->expectException(\DOMException::class);
+        $this->expectException(DOMException::class);
         $xml = '<root><nested>text';
 
         XML::formatXMLString($xml);
@@ -379,13 +386,14 @@ NOWDOC;
      * @test
      * @return void
      */
-    public function testIsValidMalformedXml()
+    public function testIsValidMalformedXml(): void
     {
         $xml = '<root><nested>text';
 
         $res = XML::isValid($xml, 'unused');
-        $expected = 'Failed to parse XML string for schema validation';
+        $this->assertIsString($res);
 
+        $expected = 'Failed to parse XML string for schema validation';
         $this->assertContains($expected, $res);
     }
 
@@ -394,12 +402,12 @@ NOWDOC;
      * @covers \SimpleSAML\Utils\XML::isValid
      * @return void
      */
-    public function testIsValidMetadata()
+    public function testIsValidMetadata(): void
     {
         $schema = 'saml-schema-metadata-2.0.xsd';
         $xml = file_get_contents(self::FRAMEWORK . '/metadata/xml/valid-metadata-selfsigned.xml');
 
-        $dom = new \DOMDocument('1.0');
+        $dom = new DOMDocument('1.0');
         $dom->loadXML($xml, LIBXML_NONET);
 
         $res = XML::isValid($dom, $schema);
@@ -410,9 +418,9 @@ NOWDOC;
      * @covers \SimpleSAML\Utils\XML::checkSAMLMessage()
      * @return void
      */
-    public function testCheckSAMLMessageInvalidType()
+    public function testCheckSAMLMessageInvalidType(): void
     {
-        $this->expectException(\InvalidArgumentException::class);
+        $this->expectException(InvalidArgumentException::class);
         XML::checkSAMLMessage('<test></test>', 'blub');
     }
 }
