@@ -1,19 +1,24 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test\Module\core\Auth\Process;
 
-// Alias the PHPUnit 6.0 ancestor if available, else fall back to legacy ancestor
-if (class_exists('\PHPUnit\Framework\TestCase', true) and !class_exists('\PHPUnit_Framework_TestCase', true)) {
-    class_alias('\PHPUnit\Framework\TestCase', '\PHPUnit_Framework_TestCase', true);
-}
+use PHPUnit\Framework\TestCase;
+use SimpleSAML\Configuration;
+use SimpleSAML\Error\Exception as SspException;
+use SimpleSAML\Module\core\Auth\Process\Cardinality;
+use SimpleSAML\Utils\HttpAdapter;
 
 /**
  * Test for the core:Cardinality filter.
  */
-class CardinalityTest extends \PHPUnit_Framework_TestCase
+class CardinalityTest extends TestCase
 {
+    /** @var \SimpleSAML\Utils\HttpAdapter|\PHPUnit_Framework_MockObject_MockObject */
     private $http;
 
+
     /**
      * Helper function to run the filter with a given configuration.
      *
@@ -21,27 +26,37 @@ class CardinalityTest extends \PHPUnit_Framework_TestCase
      * @param  array $request The request state.
      * @return array  The state array after processing.
      */
-    private function processFilter(array $config, array $request)
+    private function processFilter(array $config, array $request): array
     {
         $_SERVER['SERVER_PROTOCOL'] = 'HTTP/1.1';
         $_SERVER['REQUEST_METHOD'] = 'GET';
-        $filter = new \SimpleSAML\Module\core\Auth\Process\Cardinality($config, null, $this->http);
+
+        /** @var \SimpleSAML\Utils\HttpAdapter $http */
+        $http = $this->http;
+
+        $filter = new Cardinality($config, null, $http);
         $filter->process($request);
         return $request;
     }
 
+
+    /**
+     * @return void
+     */
     protected function setUp()
     {
-        \SimpleSAML\Configuration::loadFromArray([], '[ARRAY]', 'simplesaml');
-        $this->http = $this->getMockBuilder('SimpleSAML\Utils\HTTPAdapter')
+        Configuration::loadFromArray([], '[ARRAY]', 'simplesaml');
+        $this->http = $this->getMockBuilder(HttpAdapter::class)
                            ->setMethods(['redirectTrustedURL'])
                            ->getMock();
     }
 
-    /*
+
+    /**
      * Test where a minimum is set but no maximum
+     * @return void
      */
-    public function testMinNoMax()
+    public function testMinNoMax(): void
     {
         $config = [
             'mail' => ['min' => 1],
@@ -57,10 +72,12 @@ class CardinalityTest extends \PHPUnit_Framework_TestCase
         $this->assertEquals($expectedData, $attributes, "Assertion values should not have changed");
     }
 
-    /*
+
+    /**
      * Test where a maximum is set but no minimum
+     * @return void
      */
-    public function testMaxNoMin()
+    public function testMaxNoMin(): void
     {
         $config = [
             'mail' => ['max' => 2],
@@ -76,10 +93,12 @@ class CardinalityTest extends \PHPUnit_Framework_TestCase
         $this->assertEquals($expectedData, $attributes, "Assertion values should not have changed");
     }
 
-    /*
+
+    /**
      * Test in bounds within a maximum an minimum
+     * @return void
      */
-    public function testMaxMin()
+    public function testMaxMin(): void
     {
         $config = [
             'mail' => ['min' => 1, 'max' => 2],
@@ -95,10 +114,12 @@ class CardinalityTest extends \PHPUnit_Framework_TestCase
         $this->assertEquals($expectedData, $attributes, "Assertion values should not have changed");
     }
 
+
     /**
      * Test maximum is out of bounds results in redirect
+     * @return void
      */
-    public function testMaxOutOfBounds()
+    public function testMaxOutOfBounds(): void
     {
         $config = [
             'mail' => ['max' => 2],
@@ -109,16 +130,19 @@ class CardinalityTest extends \PHPUnit_Framework_TestCase
             ],
         ];
 
+        /** @psalm-suppress UndefinedMethod   It's a mock-object */
         $this->http->expects($this->once())
                    ->method('redirectTrustedURL');
 
         $this->processFilter($config, $request);
     }
 
+
     /**
      * Test minimum is out of bounds results in redirect
+     * @return void
      */
-    public function testMinOutOfBounds()
+    public function testMinOutOfBounds(): void
     {
         $config = [
             'mail' => ['min' => 3],
@@ -129,16 +153,19 @@ class CardinalityTest extends \PHPUnit_Framework_TestCase
             ],
         ];
 
+        /** @psalm-suppress UndefinedMethod   It's a mock-object */
         $this->http->expects($this->once())
                    ->method('redirectTrustedURL');
 
         $this->processFilter($config, $request);
     }
 
+
     /**
      * Test missing attribute results in redirect
+     * @return void
      */
-    public function testMissingAttribute()
+    public function testMissingAttribute(): void
     {
         $config = [
             'mail' => ['min' => 1],
@@ -147,23 +174,27 @@ class CardinalityTest extends \PHPUnit_Framework_TestCase
             'Attributes' => [],
         ];
 
+        /** @psalm-suppress UndefinedMethod   It's a mock-object */
         $this->http->expects($this->once())
                    ->method('redirectTrustedURL');
 
         $this->processFilter($config, $request);
     }
 
+
     /*
      * Configuration errors
      */
 
+
     /**
      * Test invalid minimum values
-     * @expectedException \SimpleSAML\Error\Exception
-     * @expectedExceptionMessageRegExp /Minimum/
+     * @return void
      */
-    public function testMinInvalid()
+    public function testMinInvalid(): void
     {
+        $this->expectException(SspException::class);
+        $this->expectExceptionMessageRegExp('/Minimum/');
         $config = [
             'mail' => ['min' => false],
         ];
@@ -175,13 +206,15 @@ class CardinalityTest extends \PHPUnit_Framework_TestCase
         $this->processFilter($config, $request);
     }
 
+
     /**
      * Test invalid minimum values
-     * @expectedException \SimpleSAML\Error\Exception
-     * @expectedExceptionMessageRegExp /Minimum/
+     * @return void
      */
-    public function testMinNegative()
+    public function testMinNegative(): void
     {
+        $this->expectException(SspException::class);
+        $this->expectExceptionMessageRegExp('/Minimum/');
         $config = [
             'mail' => ['min' => -1],
         ];
@@ -193,13 +226,15 @@ class CardinalityTest extends \PHPUnit_Framework_TestCase
         $this->processFilter($config, $request);
     }
 
+
     /**
      * Test invalid maximum values
-     * @expectedException \SimpleSAML\Error\Exception
-     * @expectedExceptionMessageRegExp /Maximum/
+     * @return void
      */
-    public function testMaxInvalid()
+    public function testMaxInvalid(): void
     {
+        $this->expectException(SspException::class);
+        $this->expectExceptionMessageRegExp('/Maximum/');
         $config = [
             'mail' => ['max' => false],
         ];
@@ -211,13 +246,15 @@ class CardinalityTest extends \PHPUnit_Framework_TestCase
         $this->processFilter($config, $request);
     }
 
+
     /**
      * Test maximum < minimum
-     * @expectedException \SimpleSAML\Error\Exception
-     * @expectedExceptionMessageRegExp /less than/
+     * @return void
      */
-    public function testMinGreaterThanMax()
+    public function testMinGreaterThanMax(): void
     {
+        $this->expectException(SspException::class);
+        $this->expectExceptionMessageRegExp('/less than/');
         $config = [
             'mail' => ['min' => 2, 'max' => 1],
         ];
@@ -229,13 +266,15 @@ class CardinalityTest extends \PHPUnit_Framework_TestCase
         $this->processFilter($config, $request);
     }
 
+
     /**
      * Test invalid attribute name
-     * @expectedException \SimpleSAML\Error\Exception
-     * @expectedExceptionMessageRegExp /Invalid attribute/
+     * @return void
      */
-    public function testInvalidAttributeName()
+    public function testInvalidAttributeName(): void
     {
+        $this->expectException(SspException::class);
+        $this->expectExceptionMessageRegExp('/Invalid attribute/');
         $config = [
             ['min' => 2, 'max' => 1],
         ];
