@@ -1,8 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test\Module\core\Auth\Process;
 
 use PHPUnit\Framework\TestCase;
+use SimpleSAML\Module\core\Auth\Process\ScopeFromAttribute;
 
 /**
  * Test for the core:ScopeFromAttribute filter.
@@ -16,9 +19,9 @@ class ScopeFromAttributeTest extends TestCase
      * @param array $request  The request state.
      * @return array  The state array after processing.
      */
-    private static function processFilter(array $config, array $request)
+    private static function processFilter(array $config, array $request): array
     {
-        $filter = new \SimpleSAML\Module\core\Auth\Process\ScopeFromAttribute($config, null);
+        $filter = new ScopeFromAttribute($config, null);
         $filter->process($request);
         return $request;
     }
@@ -28,7 +31,7 @@ class ScopeFromAttributeTest extends TestCase
      * Test the most basic functionality.
      * @return void
      */
-    public function testBasic()
+    public function testBasic(): void
     {
         $config = [
             'sourceAttribute' => 'eduPersonPrincipalName',
@@ -50,7 +53,7 @@ class ScopeFromAttributeTest extends TestCase
      * If scope already set, module must not overwrite.
      * @return void
      */
-    public function testNoOverwrite()
+    public function testNoOverwrite(): void
     {
         $config = [
             'sourceAttribute' => 'eduPersonPrincipalName',
@@ -72,7 +75,7 @@ class ScopeFromAttributeTest extends TestCase
      * If source attribute not set, nothing happens
      * @return void
      */
-    public function testNoSourceAttribute()
+    public function testNoSourceAttribute(): void
     {
         $config = [
             'sourceAttribute' => 'eduPersonPrincipalName',
@@ -93,7 +96,7 @@ class ScopeFromAttributeTest extends TestCase
      * When multiple @ signs in attribute, should use last one.
      * @return void
      */
-    public function testMultiAt()
+    public function testMultiAt(): void
     {
         $config = [
             'sourceAttribute' => 'eduPersonPrincipalName',
@@ -114,7 +117,7 @@ class ScopeFromAttributeTest extends TestCase
      * When the source attribute doesn't have a scope, a warning is emitted
      * @return void
      */
-    public function testNoAt()
+    public function testNoAt(): void
     {
         $config = [
             'sourceAttribute' => 'eduPersonPrincipalName',
