@@ -1,8 +1,12 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test\Module\core\Auth\Process;
 
+use Exception;
 use PHPUnit\Framework\TestCase;
+use SimpleSAML\Module\core\Auth\Process\TargetedID;
 
 /**
  * Test for the core:TargetedID filter.
@@ -16,9 +20,9 @@ class TargetedIDTest extends TestCase
      * @param array $request  The request state.
      * @return array  The state array after processing.
      */
-    private static function processFilter(array $config, array $request)
+    private static function processFilter(array $config, array $request): array
     {
-        $filter = new \SimpleSAML\Module\core\Auth\Process\TargetedID($config, null);
+        $filter = new TargetedID($config, null);
         $filter->process($request);
         return $request;
     }
@@ -177,9 +181,9 @@ class TargetedIDTest extends TestCase
      * Test no userid set
      * @return void
      */
-    public function testNoUserID()
+    public function testNoUserID(): void
     {
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
         $config = [];
         $request = [
             'Attributes' => [],
@@ -192,9 +196,9 @@ class TargetedIDTest extends TestCase
      * Test with specified attribute not set
      * @return void
      */
-    public function testAttributeNotExists()
+    public function testAttributeNotExists(): void
     {
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
         $config = [
             'attributename' => 'uid',
         ];
@@ -211,9 +215,9 @@ class TargetedIDTest extends TestCase
      * Test with configuration error 1
      * @return void
      */
-    public function testConfigInvalidAttributeName()
+    public function testConfigInvalidAttributeName(): void
     {
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
         $config = [
             'attributename' => 5,
         ];
@@ -230,9 +234,9 @@ class TargetedIDTest extends TestCase
      * Test with configuration error 2
      * @return void
      */
-    public function testConfigInvalidNameId()
+    public function testConfigInvalidNameId(): void
     {
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
         $config = [
             'nameId' => 'persistent',
         ];
