@@ -1,12 +1,16 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test\Module\multiauth\Auth\Source;
 
-use PHPUnit\Framework\TestCase;
+use Error;
+use Exception;
+use SimpleSAML\Test\Utils\ClearStateTestCase;
 use SimpleSAML\Configuration;
 use SimpleSAML\Module\multiauth\Auth\Source\MultiAuth;
 
-class MultiAuthTest extends \SimpleSAML\Test\Utils\ClearStateTestCase
+class MultiAuthTest extends ClearStateTestCase
 {
     /** @var Configuration */
     private $config;
@@ -70,9 +74,9 @@ class MultiAuthTest extends \SimpleSAML\Test\Utils\ClearStateTestCase
     /**
      * @return void
      */
-    public function testSourcesMustBePresent()
+    public function testSourcesMustBePresent(): void
     {
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
         $this->expectExceptionMessage('The required "sources" config option was not found');
         $sourceConfig = Configuration::loadFromArray(array(
             'example-multi' => array(
@@ -89,9 +93,9 @@ class MultiAuthTest extends \SimpleSAML\Test\Utils\ClearStateTestCase
     /**
      * @return void
      */
-    public function testPreselectMustBeValid()
+    public function testPreselectMustBeValid(): void
     {
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
         $this->expectExceptionMessage('The optional "preselect" config option must be present in "sources"');
         $sourceConfig = Configuration::loadFromArray(array(
             'example-multi' => array(
@@ -138,7 +142,7 @@ class MultiAuthTest extends \SimpleSAML\Test\Utils\ClearStateTestCase
     /**
      * @return void
      */
-    public function testPreselectIsOptional()
+    public function testPreselectIsOptional(): void
     {
         $sourceConfig = Configuration::loadFromArray(array(
             'example-multi' => array(
@@ -183,8 +187,8 @@ class MultiAuthTest extends \SimpleSAML\Test\Utils\ClearStateTestCase
 
         try {
             $source->authenticate($state);
-        } catch (\Error $e) {
-        } catch (\Exception $e) {
+        } catch (Error $e) {
+        } catch (Exception $e) {
         }
 
         $this->assertArrayNotHasKey('multiauth:preselect', $state);
@@ -194,7 +198,7 @@ class MultiAuthTest extends \SimpleSAML\Test\Utils\ClearStateTestCase
     /**
      * @return void
      */
-    public function testPreselectCanBeConfigured()
+    public function testPreselectCanBeConfigured(): void
     {
         $state = [];
 
@@ -202,7 +206,7 @@ class MultiAuthTest extends \SimpleSAML\Test\Utils\ClearStateTestCase
 
         try {
             $source->authenticate($state);
-        } catch (\Exception $e) {
+        } catch (Exception $e) {
         }
 
         $this->assertArrayHasKey('multiauth:preselect', $state);
@@ -213,7 +217,7 @@ class MultiAuthTest extends \SimpleSAML\Test\Utils\ClearStateTestCase
     /**
      * @return void
      */
-    public function testStatePreselectHasPriority()
+    public function testStatePreselectHasPriority(): void
     {
         $state = ['multiauth:preselect' => 'example-admin'];
 
@@ -221,7 +225,7 @@ class MultiAuthTest extends \SimpleSAML\Test\Utils\ClearStateTestCase
 
         try {
             $source->authenticate($state);
-        } catch (\Exception $e) {
+        } catch (Exception $e) {
         }
 
         $this->assertArrayHasKey('multiauth:preselect', $state);
