@@ -3,6 +3,6 @@
 require_once('../_include.php');
 
 // Make sure that the user has admin access rights
-SimpleSAML\Utils\Auth::requireAdmin();
+\SimpleSAML\Utils\Auth::requireAdmin();
 
 phpinfo();
