@@ -242,8 +242,15 @@ try {
         $t->data['metadataflat'] = htmlspecialchars($metaflat);
         $t->show();
     } else {
+        $etag = '"' . hash('sha256', $metaxml) . '"';
+        if (isset($_SERVER['HTTP_IF_NONE_MATCH'])) {
+            if ($_SERVER['HTTP_IF_NONE_MATCH'] === $etag) {
+                header("HTTP/1.1 304 Not Modified");
+                exit(0);
+            }
+        }
         header('Content-Type: application/samlmetadata+xml');
-
+        header('ETag: ' . $etag);
         echo $metaxml;
         exit(0);
     }
